@@ -8,6 +8,8 @@
  * BaseBuild - Creation d'une base de programmation en langage C de type GNU avec les autotools
  * GNU General Public License
  *
+ *  This file is part of XCFA.
+ * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -135,4 +137,19 @@ void libcombo_alloc (GtkComboBox *p_combo)
 		list = g_list_next (list);
 	}
 }
+// OPTIONS REMOVE COMBO
+// 	libcombo_remove_options (GTK_COMBO_BOX ());
+// 
+void libcombo_remove_options (GtkComboBox *p_combo)
+{
+	gint	Index;
+	
+	while (TRUE) {
+		Index = gtk_combo_box_get_active (GTK_COMBO_BOX (p_combo));		
+		if (Index == -1) break;
+		gtk_combo_box_remove_text (GTK_COMBO_BOX (p_combo), Index);
+		
+		gtk_combo_box_set_active (GTK_COMBO_BOX (p_combo), 0);
+	}
+}
 
