@@ -8,6 +8,8 @@
  * BaseBuild - Creation d'une base de programmation en langage C de type GNU avec les autotools
  * GNU General Public License
  *
+ *  This file is part of XCFA.
+ * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -41,13 +43,7 @@
 #endif
 
 #include <gtk/gtk.h>
-// #include <stdio.h>
-// #include <stdlib.h>
-// #include <ctype.h>
-// #include <unistd.h>
-// #include <sys/stat.h>
-// #include <sys/types.h>
-// #include <string.h>
+#include <string.h>
 
 #include "lib.h"
 
@@ -142,7 +138,73 @@ gchar *utf8_convert_to_utf8 (const gchar *string)
 	
 	return ((gchar *)output);
 }
+// 
+// UNACCENT:
+//	http://freetuxtv.blogspot.com/
+//	http://freetuxtv.blogspot.com/2010/12/ignorer-les-diacritiques-accent-trema.html
+// 
+gchar *utf8_removediacritics( const gchar *str, gssize len )
+{
+	gchar		*szNormalizedString;
+	GString		*szStringBuilder;
+	gchar		*szRes = NULL;
+	gunichar	c;
+	gchar		*szPtr = NULL;
 
+	if( NULL != str ) {
+		szNormalizedString = g_utf8_normalize( str, len, G_NORMALIZE_NFD );
+
+		szStringBuilder = g_string_new( "" );
+
+		szPtr = szNormalizedString;
+		while( szPtr ){
+			c = g_utf8_get_char( szPtr );
+			if( c != '\0' ) {
+				if( !g_unichar_ismark( c )) {
+					g_string_append_unichar( szStringBuilder, c );
+				}
+				szPtr = g_utf8_next_char( szPtr );
+			}
+			else {
+				szPtr = NULL;
+			}
+		}
+
+		szRes = g_string_free( szStringBuilder, FALSE );
+		g_free( szNormalizedString );
+	}
+
+	return szRes;
+}
+//  &AMP
+// 
+gchar *utf8_eperluette_name( gchar *p_name )
+{
+	gchar *NewName = NULL;
+	gchar *PtrNew = NULL;
+	gchar *Ptr = NULL;
+	
+	if( NULL != p_name ) {
+		NewName = g_strnfill( strlen( p_name ) * 4, '\0' );
+		PtrNew = NewName;
+		Ptr = p_name;
+		
+		while( *Ptr ) {
+			if( *Ptr == '&' && *(Ptr+1) != 'a' ) {
+				*PtrNew ++ = *Ptr ++;
+				*PtrNew ++ = 'a';
+				*PtrNew ++ = 'm';
+				*PtrNew ++ = 'p';
+				*PtrNew ++ = ';';
+			}
+			else {
+				*PtrNew ++ = *Ptr ++;
+			}
+		}
+	}
+	
+	return( NewName );
+}
 
 
 
