@@ -1,33 +1,27 @@
  /*
- * file      : cd_audio.h
- * project   : xcfa
- * with      : Gtk-2
+ *  file      : cd_audio.h
+ *  project   : xcfa
+ *  with      : Gtk-2
  *
- * copyright : (C) 2003 - 2011 by Claude Bulin
+ *  copyright : (C) 2003 - 2011 by Claude Bulin
  *
- * xcfa - GTK+ implementation of the GNU shell command
- * GNU General Public License
+ *  xcfa - GTK+ implementation of the GNU shell command
+ *  GNU General Public License
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * OLD ADRESS:
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
- * NEW ADRESS:
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
- *
- * You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ *  This file is part of XCFA.
  * 
+ *  XCFA is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  at your option) any later version.
+ * 
+ *  XCFA is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ * 
+ *  You should have received a copy of the GNU General Public License
+ *  along with XCFA.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 
@@ -88,8 +82,6 @@ typedef struct {
 	gchar			*Pathname_m3u;				// 
 	gchar			*Pathname_xspf;				// 
 
-	gboolean		 bool_dedans;				// 
-	
 	GtkWidget		*Adr_Expander;				// 
 	GtkWidget		*Adr_notebook;				// 
 	GtkWidget		*Adr_entry_tag_titre_album;		// 
@@ -135,9 +127,9 @@ extern VAR_CD var_cd;
 
 typedef enum {								// Pour extraction / conversion */
 
-	NONE,								// Aucune demande
-	WAITING,							// En attente
-	CONV_OK								// Fait
+	ETAT_CONV_CD_NONE,						// Aucune demande
+	ETAT_CONV_CD_WAITING,						// En attente
+	ETAT_CONV_CD_CONV_OK						// Fait
 
 } ETAT_CONV_CD;
 
@@ -257,7 +249,7 @@ typedef struct {
 	
 	gboolean		 EtatBoolWavpack;
 	
-} AUDIO;
+} CD_AUDIO;
 
 typedef struct {							// UN ENTETE POUR LE CD
 
@@ -267,10 +259,7 @@ typedef struct {							// UN ENTETE POUR LE CD
 	
 	gboolean		 BoolMultiArtiste;			// 
 
-	gchar			*Duree_cd;				// Duree totale du cd
-
-	unsigned long		 Num_ID_CD;				// ID du cd en numerique
-	gchar			 Str_ID_CD [ 20 ];			// ID du cd en chaine
+	gchar			*StrDureeCd;				// Duree totale du cd
 
 	gint			 TotalTracks;				// Nombre total de pistes trouvees
 	
@@ -280,8 +269,6 @@ typedef struct {							// UN ENTETE POUR LE CD
 	gint			 NumYear;				// Annee du cd en numerique
 	gchar			*StrYear;				// Annee du cd en chaine
 
-	gboolean		 Bool_Connected;			// TRUE : Connected ELSE FALSE
-
 	GList			*GList_Audio_cd;			// UNE STRUCTURE 'AUDIO' PAR PISTE
 
 	gboolean		 Bool_Read_Infos_cd;			// TRUE or FALSE
@@ -294,7 +281,8 @@ typedef struct {							// UN ENTETE POUR LE CD
 	gchar			 Str_Bitrate_oggenc [ 10 ]; 		// Bitrate pour Oggenc
 	
 	gchar			*StrMemoTagComment;			// Memorisation du commentaire
-
+	
+	gint			ForceValueGenre;			// 
 } ENTETE_CD;
 
 extern ENTETE_CD EnteteCD;
@@ -328,14 +316,14 @@ void		cdaudio_set_flag_buttons (void);
 void		cdaudio_affiche_glist_audio (void);
 void		cdaudio_update_glist (void);
 void		cdaudio_set_titre_chanson (void);
-AUDIO		*cdaudio_get_line_selected (void);
+CD_AUDIO	*cdaudio_get_line_selected (void);
 void		cdaudio_entry_stockage_cdaudio_changed (void);
 void		cdaudio_deallocate_glist_context (void);
 gboolean	cdaudio_get_bool_is_wav_extract_to_cue (void);
 void		cdaudio_put_label_titre (gchar *Messag);
 void		cdaudio_put_label_duree (gchar *Messag);
 gchar		*cdaudio_get_TitleCD (void);
-void		cdaudio_from_popup (TYPE_SET_FROM_POPUP_CD TypeSetFromPopup, AUDIO *Audio, TYPE_FILE_IS TypeFileIs);
+void		cdaudio_from_popup (TYPE_SET_FROM_POPUP_CD TypeSetFromPopup, CD_AUDIO *Audio, TYPE_FILE_IS TypeFileIs);
 
 /*
 *---------------------------------------------------------------------------
