@@ -1,33 +1,27 @@
  /*
- * file      : cd_audio_extract.c
- * project   : xcfa
- * with      : Gtk-2
+ *  file      : cd_audio_extract.c
+ *  project   : xcfa
+ *  with      : Gtk-2
  *
- * copyright : (C) 2003 - 2011 by Claude Bulin
+ *  copyright : (C) 2003 - 2011 by Claude Bulin
  *
- * xcfa - GTK+ implementation of the GNU shell command
- * GNU General Public License
+ *  xcfa - GTK+ implementation of the GNU shell command
+ *  GNU General Public License
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * OLD ADRESS:
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
- * NEW ADRESS:
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
- *
- * You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ *  This file is part of XCFA.
  * 
+ *  XCFA is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  at your option) any later version.
+ * 
+ *  XCFA is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ * 
+ *  You should have received a copy of the GNU General Public License
+ *  along with XCFA.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 /* Xcfa essayes de reprendre quelques fonctionnalites interessantes de 'rubyripper'
@@ -83,6 +77,7 @@
 #include "cd_cue.h"
 #include "notify_send.h"
 #include "win_scan.h"
+#include "popup_systray.h"
 #include "cd_audio.h"
 #include "cd_audio_extract.h"
 
@@ -155,7 +150,7 @@ GList *cdaudioextract_remove_glist (GList *New)
 void cdaudioextract_remove_list (void)
 {
 	GList		*List = NULL;
-	AUDIO		*Audio = NULL;
+	CD_AUDIO	*Audio = NULL;
 	gint		 Num;
 	gint		 Pos;
 	
@@ -179,7 +174,7 @@ void cdaudioextract_remove_list (void)
 }
 // SAUVEGARDE DES POINTEURS
 // 
-void cdaudioextract_save_arg_from_conv (AUDIO *Audio, gint p_Num)
+void cdaudioextract_save_arg_from_conv (CD_AUDIO *Audio, gint p_Num)
 {
 	gint	Pos;
 
@@ -191,7 +186,7 @@ void cdaudioextract_save_arg_from_conv (AUDIO *Audio, gint p_Num)
 }
 // 
 // 
-void cdaudioextract_save_arg_from_extract (AUDIO *Audio, gint p_Num)
+void cdaudioextract_save_arg_from_extract (CD_AUDIO *Audio, gint p_Num)
 {
 	gint	Pos;
 
@@ -203,7 +198,7 @@ void cdaudioextract_save_arg_from_extract (AUDIO *Audio, gint p_Num)
 }
 // RESTITUTION DES POINTEURS
 // 
-void cdaudioextract_restitue_arg_to_conv (AUDIO *Audio, gint p_Num)
+void cdaudioextract_restitue_arg_to_conv (CD_AUDIO *Audio, gint p_Num)
 {
 	gint	Pos;
 
@@ -215,7 +210,7 @@ void cdaudioextract_restitue_arg_to_conv (AUDIO *Audio, gint p_Num)
 }
 // 
 // 
-void cdaudioextract_restitue_arg_to_extract (AUDIO *Audio, gint p_Num)
+void cdaudioextract_restitue_arg_to_extract (CD_AUDIO *Audio, gint p_Num)
 {
 	gint	Pos;
 	
@@ -230,13 +225,13 @@ void cdaudioextract_restitue_arg_to_extract (AUDIO *Audio, gint p_Num)
 void cdaudioextract_create_list_is_Convert (void)
 {
 	GList		*List = NULL;
-	AUDIO		*Audio = NULL;
+	CD_AUDIO	*Audio = NULL;
 	PARAM_FILELC	 param_filelc;
 	
 	List = g_list_first (EnteteCD.GList_Audio_cd);
 	while (List) {
 		if (NULL != (Audio = List->data)) {
-			if (Audio->Etat_Sox == WAITING) {
+			if (Audio->Etat_Sox == ETAT_CONV_CD_WAITING) {
 				if (NULL != VarCdExtract.NameFileFormatUnique) {
 					
 					gchar *Ptr = NULL;
@@ -275,7 +270,7 @@ void cdaudioextract_create_list_is_Convert (void)
 				}
 			}
 			
-			if (Audio->Etat_Sox == WAITING || Audio->Etat_Flac == WAITING) {
+			if (Audio->Etat_Sox == ETAT_CONV_CD_WAITING || Audio->Etat_Flac == ETAT_CONV_CD_WAITING) {
 				param_filelc.type_conv             = FLAC_WAV_TO_FLAC;
 				param_filelc.With_CommandLineUser  = Audio->EtatSelection_Flac >= CD_ETAT_SELECT_EXPERT;
 				
@@ -297,7 +292,7 @@ void cdaudioextract_create_list_is_Convert (void)
 				filelc_get_command_line (&param_filelc);
 				cdaudioextract_save_arg_from_conv (Audio, NUM_FLAC);
 			}
-			if (Audio->Etat_Ape == WAITING) {
+			if (Audio->Etat_Ape == ETAT_CONV_CD_WAITING) {
 				param_filelc.type_conv             = MAC_WAV_TO_APE;
 				param_filelc.With_CommandLineUser  = Audio->EtatSelection_Ape >= CD_ETAT_SELECT_EXPERT;
 				param_filelc.filesrc               = Audio->PathName_Dest_Wav;
@@ -312,7 +307,7 @@ void cdaudioextract_create_list_is_Convert (void)
 				filelc_get_command_line (&param_filelc);
 				cdaudioextract_save_arg_from_conv (Audio, NUM_APE);
 			}
-			if (Audio->Etat_WavPack == WAITING) {
+			if (Audio->Etat_WavPack == ETAT_CONV_CD_WAITING) {
 				param_filelc.type_conv             = WAVPACK_WAV_TO_WAVPACK;
 				param_filelc.With_CommandLineUser  = Audio->EtatSelection_WavPack >= CD_ETAT_SELECT_EXPERT;
 				param_filelc.filesrc               = Audio->PathName_Dest_Wav;
@@ -327,7 +322,7 @@ void cdaudioextract_create_list_is_Convert (void)
 				filelc_get_command_line (&param_filelc);
 				cdaudioextract_save_arg_from_conv (Audio, NUM_WAVPACK);
 			}
-			if (Audio->Etat_Sox == WAITING || Audio->Etat_Ogg == WAITING) {
+			if (Audio->Etat_Sox == ETAT_CONV_CD_WAITING || Audio->Etat_Ogg == ETAT_CONV_CD_WAITING) {
 				param_filelc.type_conv             = OGGENC_WAV_TO_OGG;
 				param_filelc.With_CommandLineUser  = Audio->EtatSelection_Ogg >= CD_ETAT_SELECT_EXPERT;
 				
@@ -350,7 +345,7 @@ void cdaudioextract_create_list_is_Convert (void)
 				filelc_get_command_line (&param_filelc);
 				cdaudioextract_save_arg_from_conv (Audio, NUM_OGG);
 			}
-			if (Audio->Etat_m4a == WAITING) {
+			if (Audio->Etat_m4a == ETAT_CONV_CD_WAITING) {
 				param_filelc.type_conv             = FAAC_WAV_TO_M4A;
 				param_filelc.With_CommandLineUser  = Audio->EtatSelection_M4a >= CD_ETAT_SELECT_EXPERT;
 				param_filelc.filesrc               = Audio->PathName_Dest_Wav;
@@ -365,7 +360,7 @@ void cdaudioextract_create_list_is_Convert (void)
 				filelc_get_command_line (&param_filelc);
 				cdaudioextract_save_arg_from_conv (Audio, NUM_M4A);
 			}
-			if (Audio->Etat_Aac == WAITING) {
+			if (Audio->Etat_Aac == ETAT_CONV_CD_WAITING) {
 				param_filelc.type_conv             = AACPLUSENC_WAV_TO_AAC;
 				param_filelc.With_CommandLineUser  = Audio->EtatSelection_Aac >= CD_ETAT_SELECT_EXPERT;
 				param_filelc.filesrc               = Audio->PathName_Dest_Wav;
@@ -381,7 +376,7 @@ void cdaudioextract_create_list_is_Convert (void)
 				filelc_get_command_line (&param_filelc);
 				cdaudioextract_save_arg_from_conv (Audio, NUM_AAC);
 			}
-			if (Audio->Etat_Sox == WAITING || Audio->Etat_Mpc == WAITING) {
+			if (Audio->Etat_Sox == ETAT_CONV_CD_WAITING || Audio->Etat_Mpc == ETAT_CONV_CD_WAITING) {
 				param_filelc.type_conv             = MPPENC_WAV_TO_MPC;
 				param_filelc.With_CommandLineUser  = Audio->EtatSelection_Mpc >= CD_ETAT_SELECT_EXPERT;
 				
@@ -403,7 +398,7 @@ void cdaudioextract_create_list_is_Convert (void)
 				filelc_get_command_line (&param_filelc);
 				cdaudioextract_save_arg_from_conv (Audio, NUM_MPC);
 			}
-			if (Audio->Etat_Mp3 == WAITING) {
+			if (Audio->Etat_Mp3 == ETAT_CONV_CD_WAITING) {
 				param_filelc.type_conv             = LAME_WAV_TO_MP3;
 				param_filelc.With_CommandLineUser  = Audio->EtatSelection_Mp3 >= CD_ETAT_SELECT_EXPERT;
 				param_filelc.filesrc               = Audio->PathName_Dest_Wav;
@@ -438,7 +433,7 @@ size_t cdaudioextract_get_size (gint NumTrack)
 gboolean cdaudioextract_create_list_is_Extract (void)
 {
 	GList		*List = NULL;
-	AUDIO		*Audio = NULL;
+	CD_AUDIO	*Audio = NULL;
 	PARAM_FILELC	 param_filelc;
 	gboolean	 BoolIsPeakAlbum = FALSE;
 
@@ -446,7 +441,7 @@ gboolean cdaudioextract_create_list_is_Extract (void)
 	List = g_list_first (EnteteCD.GList_Audio_cd);
 	while (List) {
 		if (NULL != (Audio = List->data)) {
-			if (Audio->Etat_Wav == WAITING) {
+			if (Audio->Etat_Wav == ETAT_CONV_CD_WAITING) {
 				
 				Audio->ListConv = (LIST_CONV *)g_malloc0 (sizeof(LIST_CONV) * (NUM_TOTAL + 2));
 				
@@ -731,7 +726,7 @@ void cdaudioextract_copy_src_to_dest (gchar *FileExtarct_1, gchar *FileExtarct_2
 static void cdaudioextract_thread_extraction_from_cd (void *arg)
 {
 	GList         *ListOne = NULL;
-	AUDIO         *Audio = NULL;
+	CD_AUDIO      *Audio = NULL;
 	gint           pos;
 
 	conv.bool_thread_extract  = TRUE;
@@ -743,9 +738,9 @@ static void cdaudioextract_thread_extraction_from_cd (void *arg)
 	ListOne = g_list_first (EnteteCD.GList_Audio_cd);
 	while (FALSE == conv.bool_stop && NULL != ListOne) {
 
-		if (NULL != (Audio = (AUDIO *)ListOne->data)) {
+		if (NULL != (Audio = (CD_AUDIO *)ListOne->data)) {
 
-			if (FALSE == conv.bool_stop && Audio->Etat_Wav == WAITING) {
+			if (FALSE == conv.bool_stop && Audio->Etat_Wav == ETAT_CONV_CD_WAITING) {
 
 				g_print ("\n");
 				g_print ("SOURCE CD<%s>\n", Audio->Str_Track);
@@ -851,8 +846,8 @@ static void cdaudioextract_thread_extraction_from_cd (void *arg)
 				Audio->EtatSelection_Wav = CD_ETAT_ATTENTE;
 
 				if (TRUE == conv.bool_stop) Audio->Bool_Delette_Wav = TRUE;
-				conv_inc_rip_completed ();
-				Audio->Etat_Wav = CONV_OK;
+				// conv_inc_rip_completed ();
+				Audio->Etat_Wav = ETAT_CONV_CD_CONV_OK;
 				
 				conv.Bool_MAJ_select = TRUE;
 			}
@@ -947,7 +942,9 @@ static void cdaudioextract_thread_extraction_from_cd (void *arg)
 				CdNormalise_set_normalise_ok ();
 
 				// BESOIN DE TEMPS !
-				g_usleep (1000000);
+				// g_usleep (1000000);
+				// usleep (1000000);
+				sleep (3);
 
 				// COPIE DES FICHIERS TEMPORAIRE -> DESTINATION
 				List2 = g_list_first (CdNormalise_get_list_PeakGroup ());
@@ -968,12 +965,6 @@ static void cdaudioextract_thread_extraction_from_cd (void *arg)
 	conv.bool_thread_extract = FALSE;
 	pthread_exit(0);
 }
-// 
-// 
-gboolean cdaudioextract_get_ok (void)
-{
-	return (conv.bool_thread_extract);
-}
 /*
 *---------------------------------------------------------------------------
 * THREAD CONVERSION
@@ -982,7 +973,7 @@ gboolean cdaudioextract_get_ok (void)
 static void cdaudioextract_thread_conversion_from_cd (void *arg)
 {
 	GList		*ListOne = NULL;
-	AUDIO		*Audio = NULL;
+	CD_AUDIO	*Audio = NULL;
 	gint		pos;
 	
 	conv.bool_thread_conv = TRUE;
@@ -992,7 +983,7 @@ static void cdaudioextract_thread_conversion_from_cd (void *arg)
 	ListOne = g_list_first (EnteteCD.GList_Audio_cd);
 	while (FALSE == conv.bool_stop && ListOne) {
 		
-		if (NULL == (Audio = (AUDIO *)ListOne->data)) {
+		if (NULL == (Audio = (CD_AUDIO *)ListOne->data)) {
 			ListOne = g_list_next(ListOne);
 			continue;
 		}
@@ -1008,7 +999,7 @@ static void cdaudioextract_thread_conversion_from_cd (void *arg)
 			     Audio &&
 			     Audio->EtatPeak == CD_NORM_PEAK_WAITING &&
 			     CdNormalise_get_is_list_PeakGroup () == FALSE &&
-			     Audio->Etat_Wav == CONV_OK) {
+			     Audio->Etat_Wav == ETAT_CONV_CD_CONV_OK) {
 				
 				gchar	*Name = NULL;
 				gchar	*Ptr = NULL;
@@ -1047,8 +1038,8 @@ static void cdaudioextract_thread_conversion_from_cd (void *arg)
 		
 		if (FALSE == conv.bool_stop &&
 		          Audio &&
-		          Audio->Etat_Sox == WAITING &&
-		          Audio->Etat_Wav == CONV_OK &&
+		          Audio->Etat_Sox == ETAT_CONV_CD_WAITING &&
+		          Audio->Etat_Wav == ETAT_CONV_CD_CONV_OK &&
 		          Audio->EtatPeak == CD_NORM_PEAK_NONE) {
 		          
 			VarCdExtract.PassFileUnique ++;
@@ -1058,10 +1049,10 @@ static void cdaudioextract_thread_conversion_from_cd (void *arg)
 				
 				// conv_product_name_for_label (Audio->PathName_Dest_Wav);
 				switch (VarCdExtract.ChoiceFileCue) {
-				case 0 :                              break;
-				case 1 : Audio->Etat_Flac = WAITING;  break;
-			 	case 2 : Audio->Etat_Ogg  = WAITING;  break;
-				case 3 : Audio->Etat_Mpc  = WAITING;  break;
+				case 0 :					   break;
+				case 1 : Audio->Etat_Flac = ETAT_CONV_CD_WAITING;  break;
+			 	case 2 : Audio->Etat_Ogg  = ETAT_CONV_CD_WAITING;  break;
+				case 3 : Audio->Etat_Mpc  = ETAT_CONV_CD_WAITING;  break;
 			 	}
 								
 				pos = filelc_get_command_line_nice ();
@@ -1092,13 +1083,13 @@ static void cdaudioextract_thread_conversion_from_cd (void *arg)
 				conv.Bool_MAJ_select = TRUE;
 			}
 		          
-			Audio->Etat_Sox = CONV_OK;
+			Audio->Etat_Sox = ETAT_CONV_CD_CONV_OK;
 		}
 		
 		if (FALSE == conv.bool_stop &&
 		          Audio &&
-		          Audio->Etat_Flac == WAITING &&
-		          Audio->Etat_Wav == CONV_OK &&
+		          Audio->Etat_Flac == ETAT_CONV_CD_WAITING &&
+		          Audio->Etat_Wav == ETAT_CONV_CD_CONV_OK &&
 		          Audio->EtatPeak == CD_NORM_PEAK_NONE) {
 			
 			g_print ("\n");
@@ -1117,14 +1108,14 @@ static void cdaudioextract_thread_conversion_from_cd (void *arg)
 			Audio->EtatSelection_Flac = CD_ETAT_ATTENTE;
 
 			if (TRUE == conv.bool_stop) Audio->Bool_Delette_Flac = TRUE;
-			Audio->Etat_Flac = CONV_OK;
+			Audio->Etat_Flac = ETAT_CONV_CD_CONV_OK;
 
 			conv.Bool_MAJ_select = TRUE;
 		}
 		else if (FALSE == conv.bool_stop &&
 		          Audio &&
-		          Audio->Etat_Ape == WAITING &&
-		          Audio->Etat_Wav == CONV_OK &&
+		          Audio->Etat_Ape == ETAT_CONV_CD_WAITING &&
+		          Audio->Etat_Wav == ETAT_CONV_CD_CONV_OK &&
 		          Audio->EtatPeak == CD_NORM_PEAK_NONE) {
 		          
 			g_print ("\n");
@@ -1143,14 +1134,14 @@ static void cdaudioextract_thread_conversion_from_cd (void *arg)
 			Audio->EtatSelection_Ape = CD_ETAT_ATTENTE;
 
 			if (TRUE == conv.bool_stop) Audio->Bool_Delette_Ape = TRUE;
-			Audio->Etat_Ape = CONV_OK;
+			Audio->Etat_Ape = ETAT_CONV_CD_CONV_OK;
 
 			conv.Bool_MAJ_select = TRUE;
 		}
 		else if (FALSE == conv.bool_stop &&
 		          Audio &&
-		          Audio->Etat_WavPack == WAITING &&
-		          Audio->Etat_Wav == CONV_OK &&
+		          Audio->Etat_WavPack == ETAT_CONV_CD_WAITING &&
+		          Audio->Etat_Wav == ETAT_CONV_CD_CONV_OK &&
 		          Audio->EtatPeak == CD_NORM_PEAK_NONE) {
 		          
 			gchar   *path = NULL;
@@ -1174,7 +1165,7 @@ static void cdaudioextract_thread_conversion_from_cd (void *arg)
 			Audio->EtatSelection_WavPack = CD_ETAT_ATTENTE;
 
 			if (*optionsWavpack_get_wavpack_signature_md5 () != '\0') {
-				conv.bool_set_log_wavpack = TRUE;
+				// conv.bool_set_log_wavpack = TRUE;
 			}
 
 			path = g_strdup (Audio->PathName_Dest_Wav);
@@ -1189,14 +1180,14 @@ static void cdaudioextract_thread_conversion_from_cd (void *arg)
 			path = NULL;
 
 			if (TRUE == conv.bool_stop) Audio->Bool_Delette_WavPack = TRUE;
-			Audio->Etat_WavPack = CONV_OK;
+			Audio->Etat_WavPack = ETAT_CONV_CD_CONV_OK;
 
 			conv.Bool_MAJ_select = TRUE;
 		}
 		else if (FALSE == conv.bool_stop &&
 		          Audio &&
-		          Audio->Etat_Ogg == WAITING &&
-		          Audio->Etat_Wav == CONV_OK &&
+		          Audio->Etat_Ogg == ETAT_CONV_CD_WAITING &&
+		          Audio->Etat_Wav == ETAT_CONV_CD_CONV_OK &&
 		          Audio->EtatPeak == CD_NORM_PEAK_NONE) {
 		          
 			g_print ("\n");
@@ -1215,14 +1206,14 @@ static void cdaudioextract_thread_conversion_from_cd (void *arg)
 			Audio->EtatSelection_Ogg = CD_ETAT_ATTENTE;
 
 			if (TRUE == conv.bool_stop) Audio->Bool_Delette_Ogg = TRUE;
-			Audio->Etat_Ogg = CONV_OK;
+			Audio->Etat_Ogg = ETAT_CONV_CD_CONV_OK;
 
 			conv.Bool_MAJ_select = TRUE;
 		}
 		else if (FALSE == conv.bool_stop &&
 		          Audio &&
-		          Audio->Etat_m4a == WAITING &&
-		          Audio->Etat_Wav == CONV_OK &&
+		          Audio->Etat_m4a == ETAT_CONV_CD_WAITING &&
+		          Audio->Etat_Wav == ETAT_CONV_CD_CONV_OK &&
 		          Audio->EtatPeak == CD_NORM_PEAK_NONE) {
 		          
 			g_print ("\n");
@@ -1241,14 +1232,14 @@ static void cdaudioextract_thread_conversion_from_cd (void *arg)
 			Audio->EtatSelection_M4a = CD_ETAT_ATTENTE;
 
 			if (TRUE == conv.bool_stop) Audio->Bool_Delette_M4a = TRUE;
-			Audio->Etat_m4a = CONV_OK;
+			Audio->Etat_m4a = ETAT_CONV_CD_CONV_OK;
 
 			conv.Bool_MAJ_select = TRUE;
 		}
 		else if (FALSE == conv.bool_stop &&
 		          Audio &&
-		          Audio->Etat_Aac == WAITING &&
-		          Audio->Etat_Wav == CONV_OK &&
+		          Audio->Etat_Aac == ETAT_CONV_CD_WAITING &&
+		          Audio->Etat_Wav == ETAT_CONV_CD_CONV_OK &&
 		          Audio->EtatPeak == CD_NORM_PEAK_NONE) {
 		          
 			g_print ("\n");
@@ -1267,7 +1258,7 @@ static void cdaudioextract_thread_conversion_from_cd (void *arg)
 			Audio->EtatSelection_Aac = CD_ETAT_ATTENTE;
 
 			if (TRUE == conv.bool_stop) Audio->Bool_Delette_Aac = TRUE;
-			Audio->Etat_Aac = CONV_OK;
+			Audio->Etat_Aac = ETAT_CONV_CD_CONV_OK;
 
 			conv.Bool_MAJ_select = TRUE;
 			conv.bool_percent_conv = TRUE;
@@ -1275,8 +1266,8 @@ static void cdaudioextract_thread_conversion_from_cd (void *arg)
 
 		else if (FALSE == conv.bool_stop &&
 		          Audio &&
-		          Audio->Etat_Mpc == WAITING &&
-		          Audio->Etat_Wav == CONV_OK &&
+		          Audio->Etat_Mpc == ETAT_CONV_CD_WAITING &&
+		          Audio->Etat_Wav == ETAT_CONV_CD_CONV_OK &&
 		          Audio->EtatPeak == CD_NORM_PEAK_NONE) {
 		          
 			g_print ("\n");
@@ -1295,14 +1286,14 @@ static void cdaudioextract_thread_conversion_from_cd (void *arg)
 			Audio->EtatSelection_Mpc = CD_ETAT_ATTENTE;
 
 			if (TRUE == conv.bool_stop) Audio->Bool_Delette_Mpc = TRUE;
-			Audio->Etat_Mpc = CONV_OK;
+			Audio->Etat_Mpc = ETAT_CONV_CD_CONV_OK;
 
 			conv.Bool_MAJ_select = TRUE;
 		}
 		else if (FALSE == conv.bool_stop &&
 		          Audio &&
-		          Audio->Etat_Mp3 == WAITING &&
-		          Audio->Etat_Wav == CONV_OK &&
+		          Audio->Etat_Mp3 == ETAT_CONV_CD_WAITING &&
+		          Audio->Etat_Wav == ETAT_CONV_CD_CONV_OK &&
 		          Audio->EtatPeak == CD_NORM_PEAK_NONE) {
 		          
 			g_print ("\n");
@@ -1317,11 +1308,11 @@ static void cdaudioextract_thread_conversion_from_cd (void *arg)
 			cdaudioextract_restitue_arg_to_conv (Audio, NUM_MP3);
 			conv_to_convert (Audio->ListConv[ NUM_MP3 ].WithCommandLineUser, LAME_WAV_TO_MP3, "LAME_WAV_TO_MP3");
 			filelc_get_command_line_remove ();
-
+			
 			Audio->EtatSelection_Mp3 = CD_ETAT_ATTENTE;
 
 			if (TRUE == conv.bool_stop) Audio->Bool_Delette_Mp3 = TRUE;
-			Audio->Etat_Mp3 = CONV_OK;
+			Audio->Etat_Mp3 = ETAT_CONV_CD_CONV_OK;
 
 			conv.Bool_MAJ_select = TRUE;
 		}
@@ -1333,16 +1324,16 @@ static void cdaudioextract_thread_conversion_from_cd (void *arg)
 		}
 
 		if (Audio &&
-		    Audio->Etat_Wav != WAITING &&
-		    Audio->Etat_Flac != WAITING &&
-		    Audio->Etat_Mp3 != WAITING &&
-		    Audio->Etat_Ogg != WAITING &&
-		    Audio->Etat_m4a != WAITING &&
-		    Audio->Etat_Aac != WAITING &&
-		    Audio->Etat_Mpc != WAITING &&
-		    Audio->Etat_Ape != WAITING &&
-		    Audio->Etat_WavPack != WAITING &&
-		    Audio->Etat_Sox != WAITING &&
+		    Audio->Etat_Wav != ETAT_CONV_CD_WAITING &&
+		    Audio->Etat_Flac != ETAT_CONV_CD_WAITING &&
+		    Audio->Etat_Mp3 != ETAT_CONV_CD_WAITING &&
+		    Audio->Etat_Ogg != ETAT_CONV_CD_WAITING &&
+		    Audio->Etat_m4a != ETAT_CONV_CD_WAITING &&
+		    Audio->Etat_Aac != ETAT_CONV_CD_WAITING &&
+		    Audio->Etat_Mpc != ETAT_CONV_CD_WAITING &&
+		    Audio->Etat_Ape != ETAT_CONV_CD_WAITING &&
+		    Audio->Etat_WavPack != ETAT_CONV_CD_WAITING &&
+		    Audio->Etat_Sox != ETAT_CONV_CD_WAITING &&
 		    Audio->EtatPeak == CD_NORM_PEAK_NONE) {
 
 		    	ListOne = g_list_next(ListOne);
@@ -1429,10 +1420,13 @@ static gint cdaudioextract_timeout (gpointer data)
 		
 		WindScan_set_label (Str);
 	}
-	
+	if (FALSE == conv.bool_thread_conv && FALSE == conv.bool_thread_extract && conv.total_percent < 1.0) {
+		conv.total_percent = 1.0;
+		conv.bool_percent_extract = TRUE;
+	}
 	if (TRUE == conv.bool_percent_extract || TRUE == conv.bool_percent_conv) {
 		gchar	*Str = NULL;
-			
+		
 		Str = g_strdup_printf ("%d%%", (int)(conv.total_percent * 100));
 		WindScan_set_progress (Str, conv.total_percent);
 		g_free (Str);
@@ -1440,13 +1434,15 @@ static gint cdaudioextract_timeout (gpointer data)
 		
 		if (conv.bool_percent_extract) conv.bool_percent_extract = FALSE;
 		if (conv.bool_percent_conv) conv.bool_percent_conv = FALSE;
+		if (FALSE == conv.bool_thread_conv && FALSE == conv.bool_thread_extract) return (TRUE);
 	}
 	
 	if (FALSE == conv.bool_thread_conv && FALSE == conv.bool_thread_extract) {
-		AUDIO *Audio = NULL;
-		GList *List = NULL;
-		FILE  *fp = NULL;
+		CD_AUDIO	*Audio = NULL;
+		GList		*List = NULL;
+		FILE		*fp = NULL;
 
+		PopupSystray_set_BoolMainAction (FALSE);
 		gtk_timeout_remove (conv.handler_timeout_conv);
 
 		// Creation du fichier *.m3u
@@ -1454,27 +1450,27 @@ static gint cdaudioextract_timeout (gpointer data)
 			if (NULL != (fp = fopen (var_cd.Pathname_m3u, "w"))) {
 				List = g_list_first (EnteteCD.GList_Audio_cd);
 				while (List) {
-					if (NULL != (Audio = (AUDIO *)List->data)) {
-						if (Audio->Etat_Flac == CONV_OK ||
-						    Audio->Etat_Wav == CONV_OK ||
-						    Audio->Etat_Mp3 == CONV_OK ||
-						    Audio->Etat_Ogg == CONV_OK ||
-						    Audio->Etat_m4a == CONV_OK ||
-						    Audio->Etat_Aac == CONV_OK ||
-						    Audio->Etat_Mpc == CONV_OK ||
-						    Audio->Etat_Ape == CONV_OK ||
-						    Audio->Etat_WavPack == CONV_OK) {
+					if (NULL != (Audio = (CD_AUDIO *)List->data)) {
+						if (Audio->Etat_Flac == ETAT_CONV_CD_CONV_OK ||
+						    Audio->Etat_Wav == ETAT_CONV_CD_CONV_OK ||
+						    Audio->Etat_Mp3 == ETAT_CONV_CD_CONV_OK ||
+						    Audio->Etat_Ogg == ETAT_CONV_CD_CONV_OK ||
+						    Audio->Etat_m4a == ETAT_CONV_CD_CONV_OK ||
+						    Audio->Etat_Aac == ETAT_CONV_CD_CONV_OK ||
+						    Audio->Etat_Mpc == ETAT_CONV_CD_CONV_OK ||
+						    Audio->Etat_Ape == ETAT_CONV_CD_CONV_OK ||
+						    Audio->Etat_WavPack == ETAT_CONV_CD_CONV_OK) {
 
-							if (Audio->Etat_Flac == CONV_OK)	fprintf (fp, "%s\n", Audio->PathName_Dest_Flac);
-							if (Audio->Etat_Wav == CONV_OK &&
+							if (Audio->Etat_Flac == ETAT_CONV_CD_CONV_OK)	fprintf (fp, "%s\n", Audio->PathName_Dest_Flac);
+							if (Audio->Etat_Wav == ETAT_CONV_CD_CONV_OK &&
 							    Audio->BoolM3uForWav == TRUE)	fprintf (fp, "%s\n", Audio->PathName_Dest_Wav);
-							if (Audio->Etat_Mp3 == CONV_OK)		fprintf (fp, "%s\n", Audio->PathName_Dest_Mp3);
-							if (Audio->Etat_Ogg == CONV_OK)		fprintf (fp, "%s\n", Audio->PathName_Dest_Ogg);
-							if (Audio->Etat_m4a == CONV_OK)		fprintf (fp, "%s\n", Audio->PathName_Dest_M4a);
-							if (Audio->Etat_Aac == CONV_OK)		fprintf (fp, "%s\n", Audio->PathName_Dest_Aac);
-							if (Audio->Etat_Mpc == CONV_OK)		fprintf (fp, "%s\n", Audio->PathName_Dest_Mpc);
-							if (Audio->Etat_Ape == CONV_OK)		fprintf (fp, "%s\n", Audio->PathName_Dest_Ape);
-							if (Audio->Etat_WavPack == CONV_OK)	fprintf (fp, "%s\n", Audio->PathName_Dest_WavPack);
+							if (Audio->Etat_Mp3 == ETAT_CONV_CD_CONV_OK)		fprintf (fp, "%s\n", Audio->PathName_Dest_Mp3);
+							if (Audio->Etat_Ogg == ETAT_CONV_CD_CONV_OK)		fprintf (fp, "%s\n", Audio->PathName_Dest_Ogg);
+							if (Audio->Etat_m4a == ETAT_CONV_CD_CONV_OK)		fprintf (fp, "%s\n", Audio->PathName_Dest_M4a);
+							if (Audio->Etat_Aac == ETAT_CONV_CD_CONV_OK)		fprintf (fp, "%s\n", Audio->PathName_Dest_Aac);
+							if (Audio->Etat_Mpc == ETAT_CONV_CD_CONV_OK)		fprintf (fp, "%s\n", Audio->PathName_Dest_Mpc);
+							if (Audio->Etat_Ape == ETAT_CONV_CD_CONV_OK)		fprintf (fp, "%s\n", Audio->PathName_Dest_Ape);
+							if (Audio->Etat_WavPack == ETAT_CONV_CD_CONV_OK)	fprintf (fp, "%s\n", Audio->PathName_Dest_WavPack);
 						}
 
 					}
@@ -1493,27 +1489,27 @@ static gint cdaudioextract_timeout (gpointer data)
 				
 				List = g_list_first (EnteteCD.GList_Audio_cd);
 				while (List) {
-					if (NULL != (Audio = (AUDIO *)List->data)) {
-						if (Audio->Etat_Flac == CONV_OK ||
-						    Audio->Etat_Wav == CONV_OK ||
-						    Audio->Etat_Mp3 == CONV_OK ||
-						    Audio->Etat_Ogg == CONV_OK ||
-						    Audio->Etat_m4a == CONV_OK ||
-						    Audio->Etat_Aac == CONV_OK ||
-						    Audio->Etat_Mpc == CONV_OK ||
-						    Audio->Etat_Ape == CONV_OK ||
-						    Audio->Etat_WavPack == CONV_OK) {
+					if (NULL != (Audio = (CD_AUDIO *)List->data)) {
+						if (Audio->Etat_Flac == ETAT_CONV_CD_CONV_OK ||
+						    Audio->Etat_Wav == ETAT_CONV_CD_CONV_OK ||
+						    Audio->Etat_Mp3 == ETAT_CONV_CD_CONV_OK ||
+						    Audio->Etat_Ogg == ETAT_CONV_CD_CONV_OK ||
+						    Audio->Etat_m4a == ETAT_CONV_CD_CONV_OK ||
+						    Audio->Etat_Aac == ETAT_CONV_CD_CONV_OK ||
+						    Audio->Etat_Mpc == ETAT_CONV_CD_CONV_OK ||
+						    Audio->Etat_Ape == ETAT_CONV_CD_CONV_OK ||
+						    Audio->Etat_WavPack == ETAT_CONV_CD_CONV_OK) {
 							
-							if (Audio->Etat_Flac == CONV_OK)	fprintf (fp, "        <track><location>%s</location></track>\n", Audio->PathName_Dest_Flac);
-							if (Audio->Etat_Wav == CONV_OK && Audio->BoolM3uForWav == TRUE)
+							if (Audio->Etat_Flac == ETAT_CONV_CD_CONV_OK)	fprintf (fp, "        <track><location>%s</location></track>\n", Audio->PathName_Dest_Flac);
+							if (Audio->Etat_Wav == ETAT_CONV_CD_CONV_OK && Audio->BoolM3uForWav == TRUE)
 												fprintf (fp, "        <track><location>%s</location></track>\n", Audio->PathName_Dest_Wav);
-							if (Audio->Etat_Mp3 == CONV_OK)		fprintf (fp, "        <track><location>%s</location></track>\n", Audio->PathName_Dest_Mp3);
-							if (Audio->Etat_Ogg == CONV_OK)		fprintf (fp, "        <track><location>%s</location></track>\n", Audio->PathName_Dest_Ogg);
-							if (Audio->Etat_m4a == CONV_OK)		fprintf (fp, "        <track><location>%s</location></track>\n", Audio->PathName_Dest_M4a);
-							if (Audio->Etat_Aac == CONV_OK)		fprintf (fp, "        <track><location>%s</location></track>\n", Audio->PathName_Dest_Aac);
-							if (Audio->Etat_Mpc == CONV_OK)		fprintf (fp, "        <track><location>%s</location></track>\n", Audio->PathName_Dest_Mpc);
-							if (Audio->Etat_Ape == CONV_OK)		fprintf (fp, "        <track><location>%s</location></track>\n", Audio->PathName_Dest_Ape);
-							if (Audio->Etat_WavPack == CONV_OK)	fprintf (fp, "        <track><location>%s</location></track>\n", Audio->PathName_Dest_WavPack);
+							if (Audio->Etat_Mp3 == ETAT_CONV_CD_CONV_OK)		fprintf (fp, "        <track><location>%s</location></track>\n", Audio->PathName_Dest_Mp3);
+							if (Audio->Etat_Ogg == ETAT_CONV_CD_CONV_OK)		fprintf (fp, "        <track><location>%s</location></track>\n", Audio->PathName_Dest_Ogg);
+							if (Audio->Etat_m4a == ETAT_CONV_CD_CONV_OK)		fprintf (fp, "        <track><location>%s</location></track>\n", Audio->PathName_Dest_M4a);
+							if (Audio->Etat_Aac == ETAT_CONV_CD_CONV_OK)		fprintf (fp, "        <track><location>%s</location></track>\n", Audio->PathName_Dest_Aac);
+							if (Audio->Etat_Mpc == ETAT_CONV_CD_CONV_OK)		fprintf (fp, "        <track><location>%s</location></track>\n", Audio->PathName_Dest_Mpc);
+							if (Audio->Etat_Ape == ETAT_CONV_CD_CONV_OK)		fprintf (fp, "        <track><location>%s</location></track>\n", Audio->PathName_Dest_Ape);
+							if (Audio->Etat_WavPack == ETAT_CONV_CD_CONV_OK)	fprintf (fp, "        <track><location>%s</location></track>\n", Audio->PathName_Dest_WavPack);
 						}
 					}
 					List = g_list_next(List);
@@ -1531,7 +1527,7 @@ static gint cdaudioextract_timeout (gpointer data)
 		// Delete alloc name files of extraction/conversion
 		List = g_list_first (EnteteCD.GList_Audio_cd);
 		while (List) {
-			if (NULL != (Audio = (AUDIO *)List->data)) {
+			if (NULL != (Audio = (CD_AUDIO *)List->data)) {
 					
 				if (TRUE == Audio->EtatBoolWavpack) {
 					// WinError_add_to_dsk_ (Audio->PathName_Dest_WavPack);
@@ -1651,11 +1647,6 @@ static gint cdaudioextract_timeout (gpointer data)
 		cdaudio_update_glist ();
 		cdaudio_set_flag_buttons ();
 
-		if (TRUE == conv.bool_set_log_wavpack || TRUE == conv.bool_set_log_wvunpack) {
-			conv.bool_set_log_wvunpack = FALSE;
-			conv.bool_set_log_wavpack = FALSE;
-		}
-
 		g_chdir (VarCdExtract.PtrDirActuel);
 		g_free (VarCdExtract.PtrDirActuel);	VarCdExtract.PtrDirActuel = NULL;
 		
@@ -1666,14 +1657,13 @@ static gint cdaudioextract_timeout (gpointer data)
 		cdcue_write_cue ();
 		
 		cdaudioextract_remove_list ();
+		WindScan_close ();
 		
 		if (FALSE == conv.bool_stop) {
 			NotifySend_msg (_("XCFA: Extraction CD"), _("Ok"));
 		} else {
 			NotifySend_msg (_("XCFA: Extraction CD"), _("Arret par l'utilisateur"));
 		}
-
-		WindScan_close ();
 	}
 	return (TRUE);
 }
@@ -1692,25 +1682,25 @@ ETAT_CONV_CD cdaudioextract_get_etat_sox (void)
 	if (TRUE == cdaudio_get_bool_is_wav_extract_to_cue () &&
 	    TRUE == gtk_toggle_button_get_active ( GTK_TOGGLE_BUTTON (GLADE_GET_OBJECT("checkbutton_creation_fichier_unique_cue"))) &&
 	    *Ptr != '\0') {
-		return (WAITING);
+		return (ETAT_CONV_CD_WAITING);
 	}
-	return (NONE);
+	return (ETAT_CONV_CD_NONE);
 }
 // 
 // 
 void cdaudioextract_set_flags_before_extraction (void)
 {
-	GList	*List = NULL;
-	AUDIO	*Audio = NULL;
-	gchar	*PathDest = NULL;
-	gint	 IndexExtraction;
-	gchar	*Ptr = NULL;
+	GList		*List = NULL;
+	CD_AUDIO	*Audio = NULL;
+	gchar		*PathDest = NULL;
+	gint		 IndexExtraction;
+	gchar		*Ptr = NULL;
 	
 	// PRINT_FUNC_LF();
 
 	EnteteCD.NameCD_Device = scan_get_text_combo_cd (_CD_);
 
-	if (cdaudioextract_get_etat_sox () == WAITING) {
+	if (cdaudioextract_get_etat_sox () == ETAT_CONV_CD_WAITING) {
 		VarCdExtract.BoolFormatUnique = TRUE;
 		VarCdExtract.ChoiceFileCue = gtk_combo_box_get_active ( GTK_COMBO_BOX ( GTK_WIDGET (GLADE_GET_OBJECT("combobox_choice_file_cue"))));
 		// Pour SOX
@@ -1721,7 +1711,7 @@ void cdaudioextract_set_flags_before_extraction (void)
 	IndexExtraction = 0;
 	List = g_list_first (EnteteCD.GList_Audio_cd);
 	while (List) {
-		if (NULL != (Audio = (AUDIO *)List->data)) {
+		if (NULL != (Audio = (CD_AUDIO *)List->data)) {
 			
 			cdcue_set_BoolExtract (IndexExtraction, FALSE);
 						
@@ -1732,30 +1722,30 @@ void cdaudioextract_set_flags_before_extraction (void)
 	
 			/* MAJ des flags
 			*/
-			Audio->Etat_Mp3      = Audio->EtatSelection_Mp3     >= CD_ETAT_SELECT ? WAITING : NONE;
-			Audio->Etat_Ogg      = Audio->EtatSelection_Ogg     >= CD_ETAT_SELECT ? WAITING : NONE;
-			Audio->Etat_Wav      = Audio->EtatSelection_Wav     >= CD_ETAT_SELECT ? WAITING : NONE;
-			Audio->Etat_Flac     = Audio->EtatSelection_Flac    >= CD_ETAT_SELECT ? WAITING : NONE;
-			Audio->Etat_m4a      = Audio->EtatSelection_M4a     >= CD_ETAT_SELECT ? WAITING : NONE;
-			Audio->Etat_Aac      = Audio->EtatSelection_Aac     >= CD_ETAT_SELECT ? WAITING : NONE;
-			Audio->Etat_Mpc      = Audio->EtatSelection_Mpc     >= CD_ETAT_SELECT ? WAITING : NONE;
-			Audio->Etat_Ape      = Audio->EtatSelection_Ape     >= CD_ETAT_SELECT ? WAITING : NONE;
-			Audio->Etat_WavPack  = Audio->EtatSelection_WavPack >= CD_ETAT_SELECT ? WAITING : NONE;
+			Audio->Etat_Mp3      = Audio->EtatSelection_Mp3     >= CD_ETAT_SELECT ? ETAT_CONV_CD_WAITING : ETAT_CONV_CD_NONE;
+			Audio->Etat_Ogg      = Audio->EtatSelection_Ogg     >= CD_ETAT_SELECT ? ETAT_CONV_CD_WAITING : ETAT_CONV_CD_NONE;
+			Audio->Etat_Wav      = Audio->EtatSelection_Wav     >= CD_ETAT_SELECT ? ETAT_CONV_CD_WAITING : ETAT_CONV_CD_NONE;
+			Audio->Etat_Flac     = Audio->EtatSelection_Flac    >= CD_ETAT_SELECT ? ETAT_CONV_CD_WAITING : ETAT_CONV_CD_NONE;
+			Audio->Etat_m4a      = Audio->EtatSelection_M4a     >= CD_ETAT_SELECT ? ETAT_CONV_CD_WAITING : ETAT_CONV_CD_NONE;
+			Audio->Etat_Aac      = Audio->EtatSelection_Aac     >= CD_ETAT_SELECT ? ETAT_CONV_CD_WAITING : ETAT_CONV_CD_NONE;
+			Audio->Etat_Mpc      = Audio->EtatSelection_Mpc     >= CD_ETAT_SELECT ? ETAT_CONV_CD_WAITING : ETAT_CONV_CD_NONE;
+			Audio->Etat_Ape      = Audio->EtatSelection_Ape     >= CD_ETAT_SELECT ? ETAT_CONV_CD_WAITING : ETAT_CONV_CD_NONE;
+			Audio->Etat_WavPack  = Audio->EtatSelection_WavPack >= CD_ETAT_SELECT ? ETAT_CONV_CD_WAITING : ETAT_CONV_CD_NONE;
 		
-			Audio->Etat_Sox      = NONE;
-			if (Audio->Etat_Wav == WAITING)
+			Audio->Etat_Sox      = ETAT_CONV_CD_NONE;
+			if (Audio->Etat_Wav == ETAT_CONV_CD_WAITING)
 			Audio->Etat_Sox      = cdaudioextract_get_etat_sox ();
-			if (Audio->Etat_Sox  == WAITING) conv.total_convert ++;
+			if (Audio->Etat_Sox  == ETAT_CONV_CD_WAITING) conv.total_convert ++;
 			
-			if (Audio->Etat_Mp3  == WAITING)      Audio->Etat_Wav = WAITING;
-			if (Audio->Etat_Ogg  == WAITING)      Audio->Etat_Wav = WAITING;
-			if (Audio->Etat_Flac == WAITING)      Audio->Etat_Wav = WAITING;
-			if (Audio->Etat_m4a  == WAITING)      Audio->Etat_Wav = WAITING;
-			if (Audio->Etat_Aac  == WAITING)      Audio->Etat_Wav = WAITING;
-			if (Audio->Etat_Mpc  == WAITING)      Audio->Etat_Wav = WAITING;
-			if (Audio->Etat_Ape  == WAITING)      Audio->Etat_Wav = WAITING;
-			if (Audio->Etat_WavPack  == WAITING)  Audio->Etat_Wav = WAITING;
-			if (Audio->Etat_Sox  == WAITING)      Audio->Etat_Wav = WAITING;
+			if (Audio->Etat_Mp3  == ETAT_CONV_CD_WAITING)      Audio->Etat_Wav = ETAT_CONV_CD_WAITING;
+			if (Audio->Etat_Ogg  == ETAT_CONV_CD_WAITING)      Audio->Etat_Wav = ETAT_CONV_CD_WAITING;
+			if (Audio->Etat_Flac == ETAT_CONV_CD_WAITING)      Audio->Etat_Wav = ETAT_CONV_CD_WAITING;
+			if (Audio->Etat_m4a  == ETAT_CONV_CD_WAITING)      Audio->Etat_Wav = ETAT_CONV_CD_WAITING;
+			if (Audio->Etat_Aac  == ETAT_CONV_CD_WAITING)      Audio->Etat_Wav = ETAT_CONV_CD_WAITING;
+			if (Audio->Etat_Mpc  == ETAT_CONV_CD_WAITING)      Audio->Etat_Wav = ETAT_CONV_CD_WAITING;
+			if (Audio->Etat_Ape  == ETAT_CONV_CD_WAITING)      Audio->Etat_Wav = ETAT_CONV_CD_WAITING;
+			if (Audio->Etat_WavPack  == ETAT_CONV_CD_WAITING)  Audio->Etat_Wav = ETAT_CONV_CD_WAITING;
+			if (Audio->Etat_Sox  == ETAT_CONV_CD_WAITING)      Audio->Etat_Wav = ETAT_CONV_CD_WAITING;
 			
 			/* calcul total ripping tracks
 			*/
@@ -1819,7 +1809,7 @@ void cdaudioextract_set_flags_before_extraction (void)
 				conv.TmpRep  = libutils_create_temporary_rep (Config.PathnameTMP, PATH_TMP_XCFA_AUDIOCD);
 			}
 		
-			if (Audio->Etat_Wav == WAITING) {
+			if (Audio->Etat_Wav == ETAT_CONV_CD_WAITING) {
 
 				switch (Config.ExtractCdWith) {
 				case EXTRACT_WITH_CDPARANOIA :
@@ -1974,12 +1964,14 @@ void cdaudioextract_extraction_cd_to_file_action (void)
 	VarCdExtract.PtrDirActuel = g_get_current_dir ();
 	g_chdir (conv.TmpRep);
 
+	PopupSystray_set_BoolMainAction (TRUE);
+	
  	pthread_create (&nmr_tid, NULL ,(void *)cdaudioextract_thread_conversion_from_cd, (void *)NULL);
-	pthread_detach (nmr_tid);
+	// pthread_detach (nmr_tid);
 
 	conv.bool_thread_extract = TRUE;
  	pthread_create (&nmr_tid, NULL ,(void *)cdaudioextract_thread_extraction_from_cd, (void *)NULL);
-	pthread_detach (nmr_tid);
+	// pthread_detach (nmr_tid);
 
 	PRINT("DEBUT TIMEOUT");
 	conv.handler_timeout_conv = gtk_timeout_add (50, cdaudioextract_timeout, 0);
