@@ -1,33 +1,27 @@
  /*
- * file      : cd_audio_toc.c
- * project   : xcfa
- * with      : Gtk-2
+ *  file      : cd_audio_toc.h
+ *  project   : xcfa
+ *  with      : Gtk-2
  *
- * copyright : (C) 2003 - 2011 by Claude Bulin
+ *  copyright : (C) 2003 - 2011 by Claude Bulin
  *
- * xcfa - GTK+ implementation of the GNU shell command
- * GNU General Public License
+ *  xcfa - GTK+ implementation of the GNU shell command
+ *  GNU General Public License
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * OLD ADRESS:
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
- * NEW ADRESS:
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
- *
- * You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ *  This file is part of XCFA.
  * 
+ *  XCFA is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  at your option) any later version.
+ * 
+ *  XCFA is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ * 
+ *  You should have received a copy of the GNU General Public License
+ *  along with XCFA.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 
@@ -56,11 +50,13 @@
 #include "cd_audio_extract.h"
 #include "configuser.h"
 #include "scan.h"
-#include "cdtoc.h"
 #include "cd_cue.h"
 #include "win_info.h"
 #include "win_scan.h"
 #include "cd_audio.h"
+#include "cd_cddb.h"
+#include "statusbar.h"
+#include "prg_init.h"
 
 
 
@@ -82,7 +78,9 @@
 void *cdaudiotoc_thread_do_read_toc_cd (void *data)
 {
 	var_cd.bool_thread_read_toc_cd = TRUE;
-	EnteteCD.GList_Audio_cd = (GList *)cdtoc_read ();
+	
+	EnteteCD.Bool_Read_Infos_cd = CdCddb_read_toc();
+
 	var_cd.bool_thread_read_toc_cd = FALSE;
 	pthread_exit (0);
 }
@@ -106,18 +104,18 @@ static gint cdaudiotoc_timeout_do_read_toc_cd (gpointer data)
 			if (EnteteCD.GList_Audio_cd != NULL) {
 				cdaudio_affiche_glist_audio ();
 				cdaudio_set_flag_buttons ();
-				cdaudio_put_label_duree (EnteteCD.Duree_cd);
+				cdaudio_put_label_duree (EnteteCD.StrDureeCd);
 				cdaudio_put_label_titre (EnteteCD.TitleCD);
 
 				cdaudio_entry_stockage_cdaudio_changed ();
-
+				
 				/* TO DEBUG : A VERIFIER DES QUE CONNECTION WEB EST OK
 
 				g_print ("\n");
 				g_print ("EnteteCD.TitleCD            : %s\n", EnteteCD.TitleCD);
 				g_print ("EnteteCD.Title              : %s\n", EnteteCD.Title);
 				g_print ("EnteteCD.Artiste            : %s\n", EnteteCD.Artiste);
-				g_print ("EnteteCD.Duree_cd           : %s\n", EnteteCD.Duree_cd);
+				g_print ("EnteteCD.StrDureeCd           : %s\n", EnteteCD.StrDureeCd);
 				g_print ("EnteteCD.Num_ID_CD          : %lu\n",EnteteCD.Num_ID_CD);
 				g_print ("EnteteCD.Str_ID_CD          : %s\n", EnteteCD.Str_ID_CD);
 				g_print ("EnteteCD.TotalTracks        : %d\n", EnteteCD.TotalTracks);
@@ -129,20 +127,13 @@ static gint cdaudiotoc_timeout_do_read_toc_cd (gpointer data)
 				g_print ("EnteteCD.NumYear            : %d\n", EnteteCD.NumYear);
 				g_print ("EnteteCD.StrYear            : %s\n", EnteteCD.StrYear);
 
-				g_print ("EnteteCD.Bool_Connected     : ");
-				if (EnteteCD.Bool_Connected == CONNECT_IS_FALSE)
-					g_print ("CONNECT_IS_FALSE\n");
-				else if (EnteteCD.Bool_Connected == CONNECT_IS_TRUE)
-					g_print ("CONNECT_IS_TRUE\n");
-				else if (EnteteCD.Bool_Connected == CONNECT_IS_NO_MATCH_FOUND)
-					g_print ("NO MATCH FOUND THIS CD\n");
-				else	g_print ("ERREUR: CODE A VERIFIER :(\n");
-
 				g_print ("EnteteCD.Bool_Read_Infos_cd : %s\n", EnteteCD.Bool_Read_Infos_cd ? "TRUE" : "FALSE");
 				g_print ("EnteteCD.Message            : %s\n", EnteteCD.Message);
 				*/
 			}
 		}
+		StatusBar_set_mess( NOTEBOOK_CD_AUDIO, _STATUSBAR_SIMPLE_, EnteteCD.Message);
+		StatusBar_puts();
 		var_cd.bool_timeout_read_toc_cd = FALSE;
 	
 		WindScan_close ();
@@ -160,6 +151,7 @@ void cdaudiotoc_reffresh_list_cd (void)
 	
 	if (var_cd.Adr_Combo_Box == NULL) return;
 	
+	/*
 	if (FALSE == libutils_find_file ("icedax")) {
 		PRINT_FUNC_LF();
 		wininfo_create (
@@ -168,6 +160,46 @@ void cdaudiotoc_reffresh_list_cd (void)
 		  	"");
 		return;
 	}
+	if (FALSE == libutils_find_file ("cdparanoia")) {
+		PRINT_FUNC_LF();
+		wininfo_create (
+			_("cdparanoia NOT FOUND"),
+			_("Please, install package [ cdparanoia ]"),
+		  	"");
+		return;
+	}
+	*/
+	if( FALSE == PrgInit.bool_cdda2wav ) {
+	
+		PRINT_FUNC_LF();
+		if( FALSE == libutils_find_file( "icedax" ) && FALSE == libutils_find_file( "cdda2wav" )) {
+			wininfo_create (
+				_("cdda2wav and icedax NOT FOUND"),
+				_("Please, install packages [ icedax, cdda2wav ]"),
+			  	"");
+		}
+		else if( FALSE == libutils_find_file( "icedax" )) {
+			wininfo_create (
+				_("icedax NOT FOUND"),
+				_("Please, install package [ icedax ]"),
+			  	"");
+		}
+		else if( FALSE == libutils_find_file( "cdda2wav" )) {
+			wininfo_create (
+				_("cdda2wav NOT FOUND"),
+				_("Please, install package [ cdda2wav ]"),
+			  	"");
+		}
+		return;
+	}
+	if( FALSE == PrgInit.bool_cdparanoia ) {
+		PRINT_FUNC_LF();
+		wininfo_create (
+			_("cdparanoia NOT FOUND"),
+			_("Please, install package [ cdparanoia ]"),
+		  	"");
+		return;
+	}
 	
 	WindScan_open ("Scan CD", WINDSCAN_PULSE);
 	WindScan_set_label ("<b><i>Scanning CD ...</i></b>");
@@ -181,15 +213,16 @@ void cdaudiotoc_reffresh_list_cd (void)
 	gtk_list_store_clear (var_cd.Adr_List_Store);
 
 	cdaudio_set_flag_buttons ();
-
+	
 	// recherche CDDB is TRUE
-	cddb_set_bool_cancel_cddb (FALSE);
+	CdCddb_set_bool_cancel_cddb (FALSE);
 
 	// ACTIVATION de l'update qui attends la fin du thread cd audio
 	var_cd.bool_thread_read_toc_cd = TRUE;
 	var_cd.bool_timeout_read_toc_cd = TRUE;
 	var_cd.handler_timeout_read_toc_cd = gtk_timeout_add (50, cdaudiotoc_timeout_do_read_toc_cd, 0);
 	pthread_create (&nmr_tid, NULL ,(void *)cdaudiotoc_thread_do_read_toc_cd, (void *)NULL);
+	// pthread_detach (nmr_tid);
 }
 // 
 // 
