@@ -1,33 +1,27 @@
  /*
- * file      : cd_cue.c
- * project   : xcfa
- * with      : Gtk-2
+ *  file      : cd_cue.c
+ *  project   : xcfa
+ *  with      : Gtk-2
  *
- * copyright : (C) 2003 - 2011 by Claude Bulin
+ *  copyright : (C) 2003 - 2011 by Claude Bulin
  *
- * xcfa - GTK+ implementation of the GNU shell command
- * GNU General Public License
+ *  xcfa - GTK+ implementation of the GNU shell command
+ *  GNU General Public License
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * OLD ADRESS:
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
- * NEW ADRESS:
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
- *
- * You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ *  This file is part of XCFA.
  * 
+ *  XCFA is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  at your option) any later version.
+ * 
+ *  XCFA is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ * 
+ *  You should have received a copy of the GNU General Public License
+ *  along with XCFA.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 
@@ -53,7 +47,6 @@
 
 #include "global.h"
 #include "cd_audio.h"
-#include "cdtoc.h"
 #include "get_info.h"
 #include "scan.h"
 #include "configuser.h"
@@ -105,86 +98,6 @@ gint cdcue_get_total_tracks (gchar *buffer)
 }
 // 
 // 
-void cdcue_make_cue_with_cdtoc (CD_TOC *CdToc)
-{
-	gint	i;
-	gchar	*Performer = NULL;
-	gchar	*Title = NULL;
-	gchar	*Ptr = NULL;
-	
-	if (BaseIoctl.Cue == NULL) return;
-
-	if (CdToc->TitleCD == NULL) CdToc->TitleCD = g_strdup (" ");
-	
-	Performer = g_strdup (CdToc->TitleCD);
-	if ((Ptr = strchr (Performer, '/')) != NULL) {
-		Ptr--;
-		while (*Ptr == ' ') Ptr--;
-		Ptr ++;
-		*Ptr = '\0';
-	}
-
-	if ((Ptr = strchr (CdToc->TitleCD, '/')) != NULL) {
-		Ptr ++;
-		while (*Ptr == ' ') Ptr++;
-		Title = g_strdup (Ptr);
-	}
-	else {
-		Title = g_strdup (CdToc->TitleCD);
-	}
-
-	/*
-	"James Brown / Sex Machine - The Very Best Of James Brown"
-	
-	PERFORMER "James Brown"
-	TITLE "Sex Machine - The Very Best Of James Brown"
-	
-	
-	PERFORMER "Janis Joplin"
-	TITLE "Super Hits"
-	FILE "01 - Piece Of My Heart.wav" WAVE
-	  TRACK 01 AUDIO
-	    PERFORMER "Janis Joplin"
-	    TITLE "Piece Of My Heart"
-	    INDEX 01 00:00:00
-	*/
-	
-	BaseIoctl.Performer = g_strdup (Performer);
-	BaseIoctl.Title     = g_strdup (Title);
-	/*BaseIoctl.File      = g_strdup ("XCFA_CUE.wav");*/
-	BaseIoctl.File      = g_strdup_printf ("%s.wav", Performer);
-	
-	for (i = 0; i < BaseIoctl.TotalTracks; i++) {
-		BaseIoctl.Cue [ i ].Performer = g_strdup (Performer);
-		BaseIoctl.Cue [ i ].Title     = g_strdup (CdToc->TimeTrack [ i ].TitleTrack);
-	}
-	/*
-	g_print ("CdToc->TitleCD         = %s\n", CdToc->TitleCD);
-	g_print ("CdToc->TT_Min          = %d\n", CdToc->TT_Min);
-	g_print ("CdToc->TT_Sec          = %d\n", CdToc->TT_Sec);
-	g_print ("CdToc->Str_ID_CD       = %s\n", CdToc->Str_ID_CD);
-	g_print ("CdToc->TotalTracks     = %d\n", CdToc->TotalTracks);
-	g_print ("CdToc->NumGenre        = %d\n", CdToc->NumGenre);
-	g_print ("CdToc->StrGenre        = %s\n", CdToc->StrGenre);
-	g_print ("CdToc->NumYear         = %d\n", CdToc->NumYear);
-	g_print ("CdToc->StrYear         = %s\n", CdToc->StrYear);
-
-	g_print ("CdToc->Bool_Connected  = ");
-	if (CdToc->Bool_Connected == CONNECT_IS_TRUE)			g_print ("CONNECT_IS_TRUE\n");
-	else if (CdToc->Bool_Connected == CONNECT_IS_FALSE)		g_print ("CONNECT_IS_FALSE\n");
-	else if (CdToc->Bool_Connected == CONNECT_IS_NO_MATCH_FOUND)	g_print ("CONNECT_IS_NO_MATCH_FOUND\n");
-
-	for (i = 0; i < CdToc->TotalTracks; i++)
-		if (CdToc->TimeTrack [ i ].TitleTrack)
-			g_print ("TITLE_%d = %s\n", i, CdToc->TimeTrack [ i ].TitleTrack);
-	*/
-	g_free (Performer);
-	Performer = NULL;
-	g_free (Title);
-	Title = NULL;
-}
-// 
-// 
 void cdcue_remove_base_ioctl (void)
 {
 	BaseIoctl.TotalTracks = 0;
@@ -296,109 +209,6 @@ void cdcue_print_base_ioctl (void)
 }
 // 
 // 
-void cdcue_set_base_ioctl (gchar *p_buffer,	/* Lerr			*/
-			   gint p_TotalTracks)	/* CdToc->TotalTracks	*/
-{
-	gchar		 *Lerr = NULL;
-	gchar		**Larrbuf = NULL;
-	gint		  index;
-	gchar		 *ptr = NULL;
-	gint		  piste;
-	gint		  base = 0;
-	gint		  TempDiv;
-	gint		  TempMod;
-	
-	cdcue_alloc_base_ioctl (p_TotalTracks);
-	if (BaseIoctl.Datas == NULL) {
-		PRINT("BaseIoctl.Datas == NULL");
-		return;
-	}
-	
-	Lerr = p_buffer;
-	if (*Lerr) {
-	
-		/* decoupage du texte en lignes */
-		Larrbuf = g_strsplit(Lerr, "\n", 0);
-		
-		/* debut du texte */
-		for (index=0; Larrbuf[index]; index++) {
-			if (strstr (Larrbuf[index], "===")) {
-				index ++;
-				break;
-			}
-		}
-		/*
-		Table of contents (audio tracks only):
-		track        length               begin        copy pre ch
-		===========================================================
-		  1.    12375 [02:45.00]       32 [00:00.32]    no   no  2
-		  2.    12500 [02:46.50]    12407 [02:45.32]    no   no  2
-		  3.    15925 [03:32.25]    24907 [05:32.07]    no   no  2
-		  4.    10775 [02:23.50]    40832 [09:04.32]    no   no  2
-		  5.     9550 [02:07.25]    51607 [11:28.07]    no   no  2
-		  6.    12550 [02:47.25]    61157 [13:35.32]    no   no  2
-		  7.    12613 [02:48.13]    73707 [16:22.57]    no   no  2
-		  8.    12925 [02:52.25]    86320 [19:10.70]    no   no  2
-		  9.    12550 [02:47.25]    99245 [22:03.20]    no   no  2
-		 10.    23737 [05:16.37]   111795 [24:50.45]    no   no  2
-		 11.    16363 [03:38.13]   135532 [30:07.07]    no   no  2
-		 12.    14712 [03:16.12]   151895 [33:45.20]    no   no  2
-		 13.    16325 [03:37.50]   166607 [37:01.32]    no   no  2
-		 14.    16188 [03:35.63]   182932 [40:39.07]    no   no  2
-		 15.    18800 [04:10.50]   199120 [44:14.70]    no   no  2
-		 16.    17925 [03:59.00]   217920 [48:25.45]    no   no  2
-		 17.    21212 [04:42.62]   235845 [52:24.45]    no   no  2
-		 18.    25063 [05:34.13]   257057 [57:07.32]    no   no  2
-		 19.    14112 [03:08.12]   282120 [62:41.45]    no   no  2
-		 20.    19550 [04:20.50]   296232 [65:49.57]    no   no  2
-		TOTAL  315750 [70:10.00]    (audio only)
-		*/
-		for (base = 0, piste = 0; Larrbuf[index]; index++, piste ++) {
-
-			/* calcul la fin et quitte la boucle */
-			if ((ptr = strstr (Larrbuf[index], "TOTAL"))) {
-				ptr += 5;
-				while (*ptr == ' ') ptr ++;
-				BaseIoctl.Datas[ base ].begin = atoi (ptr);
-				TempDiv = BaseIoctl.Datas[ base ].begin / 75;
-				TempMod = BaseIoctl.Datas[ base ].begin % 75;
-				BaseIoctl.Datas[ base ].begin_min  = TempDiv / 60;
-				BaseIoctl.Datas[ base ].begin_sec  = TempDiv % 60;
-				BaseIoctl.Datas[ base ].begin_cent = TempMod;
-				break;
-			}
-			
-			/* Stocke 'length' */
-			if ((ptr = strchr (Larrbuf[index], '.')) != NULL) {
-				ptr ++;
-				while (*ptr == ' ') ptr ++;
-				BaseIoctl.Datas[ base ].length = atoi (ptr);
-				TempDiv = BaseIoctl.Datas[ base ].length / 75;
-				TempMod = BaseIoctl.Datas[ base ].length % 75;
-				BaseIoctl.Datas[ base ].length_min  = TempDiv / 60;
-				BaseIoctl.Datas[ base ].length_sec  = TempDiv % 60;
-				BaseIoctl.Datas[ base ].length_cent = TempMod;
-			}
-			
-			/* Stocke 'begin' */
-			if ((ptr = strchr (Larrbuf[index], ']')) != NULL) {
-				ptr ++;
-				while (*ptr == ' ') ptr ++;
-				BaseIoctl.Datas[ base ].begin = atoi (ptr);
-				TempDiv = BaseIoctl.Datas[ base ].begin / 75;
-				TempMod = BaseIoctl.Datas[ base ].begin % 75;
-				BaseIoctl.Datas[ base ].begin_min  = TempDiv / 60;
-				BaseIoctl.Datas[ base ].begin_sec  = TempDiv % 60;
-				BaseIoctl.Datas[ base ].begin_cent = TempMod;
-				base ++;
-			}
-		}
-		g_strfreev(Larrbuf);
-		cdcue_print_base_ioctl ();
-	}
-}
-// 
-// 
 void cdcue_make_cue (void)
 {
 	gint	piste;
