@@ -1,33 +1,27 @@
  /*
- * file      : cd_expander.c
- * project   : xcfa
- * with      : Gtk-2
+ *  file      : cd_expander.c
+ *  project   : xcfa
+ *  with      : Gtk-2
  *
- * copyright : (C) 2003 - 2011 by Claude Bulin
+ *  copyright : (C) 2003 - 2011 by Claude Bulin
  *
- * xcfa - GTK+ implementation of the GNU shell command
- * GNU General Public License
+ *  xcfa - GTK+ implementation of the GNU shell command
+ *  GNU General Public License
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * OLD ADRESS:
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
- * NEW ADRESS:
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
- *
- * You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ *  This file is part of XCFA.
  * 
+ *  XCFA is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  at your option) any later version.
+ * 
+ *  XCFA is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ * 
+ *  You should have received a copy of the GNU General Public License
+ *  along with XCFA.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 
@@ -67,7 +61,7 @@ gboolean Bool_Changed_Ok = TRUE;
 // 
 void cdexpander_set_sensitive_notebook (void)
 {
-	AUDIO            *Audio = NULL;
+	CD_AUDIO	*Audio = NULL;
 	
 	if (NULL == var_cd.Adr_notebook) return;
 	Audio = cdaudio_get_line_selected ();
@@ -78,7 +72,7 @@ void cdexpander_set_sensitive_notebook (void)
 // 
 void cdexpander_set_entry_tag_titre_album (void)
 {
-	AUDIO            *Audio = NULL;
+	CD_AUDIO            *Audio = NULL;
 	
 	if (NULL == var_cd.Adr_entry_tag_titre_album) return;
 	if (NULL != (Audio = cdaudio_get_line_selected ())) {
@@ -96,7 +90,7 @@ void cdexpander_set_entry_tag_titre_album (void)
 // 
 void cdexpander_set_entry_tag_nom_artiste (void)
 {
-	AUDIO            *Audio = NULL;
+	CD_AUDIO            *Audio = NULL;
 	
 	if (NULL == var_cd.Adr_entry_tag_nom_artiste) return;
 	if (NULL != (Audio = cdaudio_get_line_selected ())) {
@@ -114,7 +108,7 @@ void cdexpander_set_entry_tag_nom_artiste (void)
 // 
 void cdexpander_set_spinbutton_tag_piste (void)
 {
-	AUDIO        *Audio = NULL;
+	CD_AUDIO        *Audio = NULL;
 	
 	if (NULL != (Audio = cdaudio_get_line_selected ()) && NULL != var_cd.Adr_spinbutton_tag_piste) {
 		Bool_Changed_Ok = FALSE;
@@ -126,7 +120,7 @@ void cdexpander_set_spinbutton_tag_piste (void)
 // 
 void cdexpander_set_spinbutton_tag_annee (void)
 {
-	AUDIO        *Audio = NULL;
+	CD_AUDIO        *Audio = NULL;
 	
 	if (NULL != (Audio = cdaudio_get_line_selected ()) && NULL != var_cd.Adr_spinbutton_tag_annee) {
 		Bool_Changed_Ok = FALSE;
@@ -147,7 +141,7 @@ gint cdexpander_get_spinbutton_tag_annee (void)
 // 
 void cdexpander_set_entry_tag_titre_chanson (void)
 {
-	AUDIO            *Audio = NULL;
+	CD_AUDIO            *Audio = NULL;
 	
 	if (NULL != (Audio = cdaudio_get_line_selected ()) && NULL != var_cd.Adr_entry_tag_titre_chanson) {
 		Bool_Changed_Ok = FALSE;
@@ -164,7 +158,7 @@ void cdexpander_set_entry_tag_titre_chanson (void)
 // 
 void cdexpander_set_new_genre (void)
 {
-	AUDIO            *Audio = NULL;
+	CD_AUDIO            *Audio = NULL;
 
 	if (NULL != (Audio = cdaudio_get_line_selected ()) && NULL != var_cd.Adr_combobox_tag_genre_cd) {
 		Bool_Changed_Ok = FALSE;
@@ -184,7 +178,7 @@ void cdexpander_set_entry_new_titre_cdaudio (gchar *p_str)
 // 
 void cdexpander_set_entry_tag_commentaire (void)
 {
-	AUDIO            *Audio = NULL;
+	CD_AUDIO            *Audio = NULL;
 	
 	if (NULL != (Audio = cdaudio_get_line_selected ()) && NULL != var_cd.Adr_entry_tag_commentaire) {
 		Bool_Changed_Ok = FALSE;
@@ -215,7 +209,7 @@ void cdexpander_set_entry_tag_titre_fichier_m3u (void)
 void on_entry_tag_titre_chanson_changed (GtkEditable *editable, gpointer user_data)
 {
 	gchar        *ptr_template = NULL;
-	AUDIO        *Audio = NULL;
+	CD_AUDIO     *Audio = NULL;
 	gchar        *str = NULL;
 	gchar        *ptr = NULL;
 	
@@ -250,7 +244,7 @@ void on_entry_tag_titre_album_changed (GtkEditable *editable, gpointer user_data
 	GtkTreeIter   iter;
 	GList        *List = NULL;
 	gchar        *ptr_template = NULL;
-	AUDIO        *Audio = NULL;
+	CD_AUDIO     *Audio = NULL;
 	
 	if (NULL == var_cd.Adr_entry_tag_titre_album) return;
 	if (FALSE == Bool_Changed_Ok) return;
@@ -259,7 +253,7 @@ void on_entry_tag_titre_album_changed (GtkEditable *editable, gpointer user_data
 	valid = gtk_tree_model_get_iter_first (var_cd.Adr_Tree_Model, &iter);
 	while (valid) {
 		List = g_list_nth (EnteteCD.GList_Audio_cd, Num_cell);
-		if (NULL != (Audio = (AUDIO *)List->data)) {
+		if (NULL != (Audio = (CD_AUDIO *)List->data)) {
 			g_free (Audio->tags->Album);
 			Audio->tags->Album = NULL;
 			Audio->tags->Album = g_strdup (ptr_template);
@@ -279,7 +273,7 @@ void on_entry_tag_nom_artiste_changed (GtkEditable *editable, gpointer user_data
 	GtkTreeIter   iter;
 	GList        *List = NULL;
 	gchar        *ptr_template = NULL;
-	AUDIO        *Audio = NULL;
+	CD_AUDIO     *Audio = NULL;
 	
 	if (NULL == var_cd.Adr_entry_tag_nom_artiste) return;
 	if (FALSE == Bool_Changed_Ok) return;
@@ -296,7 +290,7 @@ void on_entry_tag_nom_artiste_changed (GtkEditable *editable, gpointer user_data
 		valid = gtk_tree_model_get_iter_first (var_cd.Adr_Tree_Model, &iter);
 		while (valid) {
 			List = g_list_nth (EnteteCD.GList_Audio_cd, Num_cell);
-			if (NULL != (Audio = (AUDIO *)List->data)) {
+			if (NULL != (Audio = (CD_AUDIO *)List->data)) {
 				g_free (Audio->tags->Artist);
 				Audio->tags->Artist = NULL;
 				Audio->tags->Artist = g_strdup (ptr_template);
@@ -330,12 +324,12 @@ void on_button_paste_comment_clicked (GtkButton *button, gpointer user_data)
 	gboolean      valid;
 	GtkTreeIter   iter;
 	GList        *List = NULL;
-	AUDIO        *Audio = NULL;
+	CD_AUDIO     *Audio = NULL;
 	
 	valid = gtk_tree_model_get_iter_first (var_cd.Adr_Tree_Model, &iter);
 	while (valid) {
 		List = g_list_nth (EnteteCD.GList_Audio_cd, Num_cell);
-		if (NULL != (Audio = (AUDIO *)List->data)) {
+		if (NULL != (Audio = (CD_AUDIO *)List->data)) {
 			g_free (Audio->tags->Comment);
 			Audio->tags->Comment = NULL;
 			Audio->tags->Comment = g_strdup (EnteteCD.StrMemoTagComment);
@@ -355,7 +349,7 @@ void on_entry_tag_commentaire_changed (GtkEditable *editable, gpointer user_data
 	GtkTreeIter   iter;
 	GList        *List = NULL;
 	gchar        *ptr_template = NULL;
-	AUDIO        *Audio = NULL;
+	CD_AUDIO     *Audio = NULL;
 	
 	if (NULL == var_cd.Adr_entry_tag_commentaire) return;
 	if (FALSE == Bool_Changed_Ok) return;
@@ -372,7 +366,7 @@ void on_entry_tag_commentaire_changed (GtkEditable *editable, gpointer user_data
 		valid = gtk_tree_model_get_iter_first (var_cd.Adr_Tree_Model, &iter);
 		while (valid) {
 			List = g_list_nth (EnteteCD.GList_Audio_cd, Num_cell);
-			if (NULL != (Audio = (AUDIO *)List->data)) {
+			if (NULL != (Audio = (CD_AUDIO *)List->data)) {
 				g_free (Audio->tags->Comment);
 				Audio->tags->Comment = NULL;
 				Audio->tags->Comment = g_strdup (ptr_template);
@@ -391,7 +385,7 @@ void on_spinbutton_tag_annee_value_changed (GtkSpinButton *spinbutton, gpointer
 	gboolean      valid;
 	GtkTreeIter   iter;
 	GList        *List = NULL;
-	AUDIO        *Audio = NULL;
+	CD_AUDIO     *Audio = NULL;
 	gint          Value;
 	
 	if (NULL == var_cd.Adr_spinbutton_tag_annee) return;
@@ -409,7 +403,7 @@ void on_spinbutton_tag_annee_value_changed (GtkSpinButton *spinbutton, gpointer
 		valid = gtk_tree_model_get_iter_first (var_cd.Adr_Tree_Model, &iter);
 		while (valid) {
 			List = g_list_nth (EnteteCD.GList_Audio_cd, Num_cell);
-			if (NULL != (Audio = (AUDIO *)List->data)) {
+			if (NULL != (Audio = (CD_AUDIO *)List->data)) {
 				g_free (Audio->tags->Year);
 				Audio->tags->Year = NULL;
 				Audio->tags->Year = g_strdup_printf ("%d", Value);
@@ -425,7 +419,7 @@ void on_spinbutton_tag_annee_value_changed (GtkSpinButton *spinbutton, gpointer
 // 
 void on_spinbutton_tag_piste_value_changed (GtkSpinButton *spinbutton, gpointer user_data)
 {
-	AUDIO        *Audio = NULL;
+	CD_AUDIO     *Audio = NULL;
 	gint          Value;
 	
 	if (NULL == var_cd.Adr_spinbutton_tag_piste) return;
@@ -469,7 +463,7 @@ void on_combobox_tag_genre_cd_changed (GtkComboBox *combobox, gpointer user_data
 	GtkTreeIter   iter;
 	GList        *List = NULL;
 	gchar        *ptr_template = NULL;
-	AUDIO        *Audio = NULL;
+	CD_AUDIO     *Audio = NULL;
 	gint          IntGenre;
 	
 	if (NULL == var_cd.Adr_combobox_tag_genre_cd) return;
@@ -489,7 +483,7 @@ void on_combobox_tag_genre_cd_changed (GtkComboBox *combobox, gpointer user_data
 		valid = gtk_tree_model_get_iter_first (var_cd.Adr_Tree_Model, &iter);
 		while (valid) {
 			List = g_list_nth (EnteteCD.GList_Audio_cd, Num_cell);
-			if (NULL != (Audio = (AUDIO *)List->data)) {
+			if (NULL != (Audio = (CD_AUDIO *)List->data)) {
 				g_free (Audio->tags->Genre);
 				Audio->tags->Genre = NULL;
 				Audio->tags->Genre = g_strdup (ptr_template);
@@ -603,7 +597,9 @@ void on_combobox_tag_genre_cd_realize (GtkWidget *widget, gpointer user_data)
 	libcombo_alloc (GTK_COMBO_BOX (widget));
 	
 	tags_set_elements_combobox (widget);
+	// tags_set_elements_comboboxCD (widget);
 	gtk_combo_box_set_wrap_width (GTK_COMBO_BOX (widget), 4);
+	
 	gtk_combo_box_set_active (GTK_COMBO_BOX (widget), 0);
 	var_cd.Adr_combobox_tag_genre_cd = GTK_COMBO_BOX (widget);
 }
