@@ -1,33 +1,27 @@
  /*
- * file      : configuser.c
- * project   : xcfa
- * with      : Gtk-2
+ *  file      : configuser.c
+ *  project   : xcfa
+ *  with      : Gtk-2
  *
- * copyright : (C) 2003 - 2011 by Claude Bulin
+ *  copyright : (C) 2003 - 2011 by Claude Bulin
  *
- * xcfa - GTK+ implementation of the GNU shell command
- * GNU General Public License
+ *  xcfa - GTK+ implementation of the GNU shell command
+ *  GNU General Public License
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * OLD ADRESS:
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
- * NEW ADRESS:
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
- *
- * You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ *  This file is part of XCFA.
  * 
+ *  XCFA is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  at your option) any later version.
+ * 
+ *  XCFA is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ * 
+ *  You should have received a copy of the GNU General Public License
+ *  along with XCFA.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 
@@ -56,6 +50,7 @@
 #include "configuser.h"
 
 
+
 VAR_CONFIG ConfigSaveToRest;	// Pour les restitutions par defaut
 VAR_CONFIG Config = {
 	FALSE,		// BoolConfigOk
@@ -88,8 +83,7 @@ VAR_CONFIG Config = {
 	0,		// NotebookFile
 	0,		// NotebookPochette
 	0,		// NotebookOptions
-	0,		// NotebookAppExterns;
-	TRUE,		// ReadCdByIoctl
+	0,		// NotebookAppExterns
 	0,		// ExtractCdWith = EXTRACT_WITH_CDPARANOIA = 0
 	1,		// BitrateLameIndice
 	{0,8,0,0},	// TabBitrateLame
@@ -146,9 +140,9 @@ VAR_CONFIG Config = {
 	NULL,		// StringParamNameLecteurAudio
 	NULL,		// StringBoolFieldsIsVisible	FIELDS DVD,CD,FILES : FALSE or HIDE = 0, TRUE or SHOW = 1
 	NULL,		// StringPosFieldsName		POS NAME OF DVD,CD,FILES: 0 = LEFT, 1 = CENTER, 2 = RIGHT
+	0,		// NumSelectComboBoxDvd
 	0,		// NumSelectComboBoxCd
-	NULL,		// entry_cddp_server
-	NULL		// entry_cddp_port
+	NULL		// entry_cddp_server
 };
 
 
@@ -371,12 +365,12 @@ void config_read (void)
 		if (FALSE == config_read_value_atoi (buf, "IND_COMBO_DEST_FILE_WAV",		&Config.TabIndiceComboDestFile[1],	0,	2))
 		if (FALSE == config_read_value_atoi (buf, "IND_COMBO_DEST_FILE_MP3OGG",		&Config.TabIndiceComboDestFile[2],	0,	2))
 		if (FALSE == config_read_value_atoi (buf, "IND_COMBO_DEST_FILE_TAGS",		&Config.TabIndiceComboDestFile[3],	0,	2))
-		if (FALSE == config_read_value_atoi (buf, "SERVER_FREE_CDDB",			&Config.ServeurCddb,			0,	2))
+		if (FALSE == config_read_value_atoi (buf, "SERVER_FREE_CDDB",			&Config.ServeurCddb,			0,	1))
+		if (FALSE == config_read_value_atoi (buf, "NUM_SELECT_COMBOBOX_DVD",		&Config.NumSelectComboBoxDvd,		0,	10))
 		if (FALSE == config_read_value_atoi (buf, "NUM_SELECT_COMBOBOX_CD",		&Config.NumSelectComboBoxCd,		0,	10))
 		
 		// READ BOOL
 		// 
-		if (FALSE == config_read_value_bool (buf, "READ_CD_BY_IOCTL",			&Config.ReadCdByIoctl))
 		if (FALSE == config_read_value_bool (buf, "TAGS_ARTISTE",			&Config.BoolArtistTag))
 		if (FALSE == config_read_value_bool (buf, "TAGS_TITLE",				&Config.BoolTitleTag))
 		if (FALSE == config_read_value_bool (buf, "TAGS_ALBUM",				&Config.BoolAlbumTag))
@@ -427,8 +421,7 @@ void config_read (void)
 		if (FALSE == config_read_value_str (buf, "STRING_BOOL_FIELD_IS_VISIBLE",	&Config.StringBoolFieldsIsVisible))
 		if (FALSE == config_read_value_str (buf, "STRING_POS_FIELD_IS_NAME",		&Config.StringPosFieldsName))
 		
-		if (FALSE == config_read_value_str (buf, "STRING_ENTRY_CDDP_SERVER",		&Config.entry_cddp_server))
-		if (FALSE == config_read_value_str (buf, "STRING_ENTRY_CDDP_PORT",		&Config.entry_cddp_port));
+		if (FALSE == config_read_value_str (buf, "STRING_ENTRY_CDDP_SERVER",		&Config.entry_cddp_server));
 		
 		buf [ 0 ] = '\0';
 	}
@@ -507,7 +500,7 @@ void config_save (void)
 		fprintf (fp, "NOTEBOOK_POCHETTE                   = %d\n", Config.NotebookPochette);
 		fprintf (fp, "NOTEBOOK_OPTIONS                    = %d\n", Config.NotebookOptions);
 		fprintf (fp, "NOTEBOOK_APP_EXTERNS                = %d\n", Config.NotebookAppExterns);
-		fprintf (fp, "READ_CD_BY_IOCTL                    = %s\n", Config.ReadCdByIoctl == TRUE ? "TRUE" : "FALSE");
+		
 		fprintf (fp, "EXTRACT_CD_WITH                     = %d\n", Config.ExtractCdWith);
 		
 		fprintf (fp, "OPTIONS_BITRATE_LAME                = %d\n", Config.BitrateLameIndice);
@@ -565,7 +558,6 @@ void config_save (void)
 		
 		fprintf (fp, "SERVER_FREE_CDDB                    = %d\n", Config.ServeurCddb);
 		fprintf (fp, "STRING_ENTRY_CDDP_SERVER            = %s\n", Config.entry_cddp_server != NULL ? Config.entry_cddp_server : "freedb.freedb.org");
-		fprintf (fp, "STRING_ENTRY_CDDP_PORT              = %s\n", Config.entry_cddp_port != NULL ? Config.entry_cddp_port : "8880");
 		
 		fprintf (fp, "STRING_NAME_FILE_M3U_XSPF           = %s\n", Config.StringNameFile_m3u_xspf ? Config.StringNameFile_m3u_xspf : "");
 		fprintf (fp, "TEMPLATE_TITLE_CDAUDIO              = ");
@@ -603,8 +595,15 @@ void config_save (void)
 		fprintf (fp, "STRING_BOOL_FIELD_IS_VISIBLE        = %s\n", Config.StringBoolFieldsIsVisible ? Config.StringBoolFieldsIsVisible : "");
 		fprintf (fp, "STRING_POS_FIELD_IS_NAME            = %s\n", Config.StringPosFieldsName ? Config.StringPosFieldsName : "");
 		
+		fprintf (fp, "NUM_SELECT_COMBOBOX_DVD             = %d\n", Config.NumSelectComboBoxDvd);
 		fprintf (fp, "NUM_SELECT_COMBOBOX_CD              = %d\n", Config.NumSelectComboBoxCd);
 		
+		// TODO: RESERVED
+		// g_sprintf( String, "%08lx", ret );
+		// long atol( const char *nptr );
+		// La fonction atol() convertit le début de la chaîne pointée par nptr en entier de type long
+		// The atol() function converts the initial portion of the string pointed to by nptr to long
+		
 		fprintf (fp, "\n");
 		fclose (fp);
 	}
@@ -649,6 +648,5 @@ void config_remove (void)
 	g_free (Config.StringBoolFieldsIsVisible);	Config.StringBoolFieldsIsVisible = NULL;
 	g_free (Config.StringPosFieldsName);		Config.StringPosFieldsName = NULL;
 	g_free (Config.entry_cddp_server);		Config.entry_cddp_server = NULL;
-	g_free (Config.entry_cddp_port);		Config.entry_cddp_port = NULL;
 }
 
