@@ -1,33 +1,27 @@
  /*
- * file      : conv.c
- * project   : xcfa
- * with      : Gtk-2
+ *  file      : conv.c
+ *  project   : xcfa
+ *  with      : Gtk-2
  *
- * copyright : (C) 2003 - 2011 by Claude Bulin
+ *  copyright : (C) 2003 - 2011 by Claude Bulin
  *
- * xcfa - GTK+ implementation of the GNU shell command
- * GNU General Public License
+ *  xcfa - GTK+ implementation of the GNU shell command
+ *  GNU General Public License
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * OLD ADRESS:
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
- * NEW ADRESS:
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
- *
- * You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ *  This file is part of XCFA.
  * 
+ *  XCFA is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  at your option) any later version.
+ * 
+ *  XCFA is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ * 
+ *  You should have received a copy of the GNU General Public License
+ *  along with XCFA.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 
@@ -102,8 +96,6 @@ void conv_inc_rip_completed (void)
 					(double)conv.extract_percent +
 					(double)conv.conversion_percent) /
 					((double)conv.total_rip + (double)conv.total_convert);
-		// PRINT_FUNC_LF();
-		// conv_print ();
 	}
 	conv.bool_percent_conv = TRUE;
 }
@@ -116,8 +108,6 @@ void conv_inc_encode_completed (void)
 					(double)conv.extract_percent +
 					(double)conv.conversion_percent) /
 					((double)conv.total_rip + (double)conv.total_convert);
-		// PRINT_FUNC_LF();
-		// conv_print ();
 	}
 	conv.bool_percent_conv = TRUE;
 }
@@ -262,8 +252,6 @@ void conv_reset_struct (void *p_func)
 	conv.total_percent = 0.0;
 	conv.bool_percent_conv = FALSE;
 	conv.bool_percent_extract = FALSE;
-	conv.bool_set_log_wvunpack = FALSE;
-	conv.bool_set_log_wavpack = FALSE;
 			
 	conv.bool_stop = FALSE;
 
@@ -1991,7 +1979,7 @@ gboolean conv_to_convert (gboolean WithParameter, TYPE_CONV type_conv, gchar *in
 	gint             pos = 0;
 	gboolean	 RetBool = TRUE;
 		
-	// PRINT_FUNC_LF();
+	PRINT_FUNC_LF();
 	
 	if (NORMALISE_CALCUL == type_conv || NORMALISE_APPLIQUE == type_conv || NORMALISE_EXEC == type_conv || NORMALISE_GET_LEVEL == type_conv) {
 		conv.BoolIsNormalise = TRUE;
