@@ -1,33 +1,27 @@
  /*
- * file      : file_analyse.c
- * project   : xcfa
- * with      : Gtk-2
+ *  file      : file_analyse.c
+ *  project   : xcfa
+ *  with      : Gtk-2
  *
- * copyright : (C) 2003 - 2011 by Claude Bulin
+ *  copyright : (C) 2003 - 2011 by Claude Bulin
  *
- * xcfa - GTK+ implementation of the GNU shell command
- * GNU General Public License
+ *  xcfa - GTK+ implementation of the GNU shell command
+ *  GNU General Public License
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * OLD ADRESS:
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
- * NEW ADRESS:
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
- *
- * You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ *  This file is part of XCFA.
  * 
+ *  XCFA is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  at your option) any later version.
+ * 
+ *  XCFA is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ * 
+ *  You should have received a copy of the GNU General Public License
+ *  along with XCFA.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 
@@ -65,6 +59,7 @@
 #include "win_scan.h"
 #include "prg_init.h"
 #include "win_info.h"
+#include "popup_systray.h"
 #include "file.h"
 
 
@@ -536,8 +531,14 @@ void fileanalyze_set_in_list (void)
 			else if (VarListFiles->TypeFileIs == FILE_IS_AC3)     detail->info = tagsac3_get_info (detail);
 			else						      detail->info = NULL;
 			
-			// INSERTION DE LA STRUCTURE DETAIL DANS LA LISTE ENTETEFILE
-			entetefile = g_list_append (entetefile, detail);
+			// 
+			// CONDITION AJOUTEE SUITE A POST DEPUIS:
+			//	http://forum.ubuntu-fr.org/viewtopic.php?pid=4018344#p4018344
+			// 
+			if (NULL != detail->info) {
+				// INSERTION DE LA STRUCTURE DETAIL DANS LA LISTE ENTETEFILE
+				entetefile = g_list_append (entetefile, detail);
+			}
 			
 			g_free (VarListFiles->Name);
 			VarListFiles->Name = NULL;
@@ -602,6 +603,7 @@ static gint fileanalyze_timeout (gpointer data)
 	}
 	else if (FALSE == VarAnalyze.BoolInThread) {
 		WindScan_close ();
+		PopupSystray_set_BoolMainAction (FALSE);
 		gtk_timeout_remove (VarAnalyze.HandlerTimeoutDo);
 		file_affiche_glist ();
 		FileWav_affiche_glist ();
@@ -651,6 +653,8 @@ void fileanalyze_add_file_to_treeview (TYPE_FILESELECTION p_TypeFileselection, G
 	VarAnalyze.BoolSetPercent = FALSE;
 	VarAnalyze.BoolNoFindCheckMp3 = FALSE;
 	
+	PopupSystray_set_BoolMainAction (TRUE);
+	
 	pthread_create (&nmr_tid_1, NULL ,(void *)fileanalyze_thread, (void *)NULL);
 	VarAnalyze.HandlerTimeoutDo = gtk_timeout_add (100, fileanalyze_timeout, 0);
 }
