@@ -1,33 +1,27 @@
  /*
- * file      : file_mp3ogg.c
- * project   : xcfa
- * with      : Gtk-2
+ *  file      : file_mp3ogg.c
+ *  project   : xcfa
+ *  with      : Gtk-2
  *
- * copyright : (C) 2003 - 2011 by Claude Bulin
+ *  copyright : (C) 2003 - 2011 by Claude Bulin
  *
- * xcfa - GTK+ implementation of the GNU shell command
- * GNU General Public License
+ *  xcfa - GTK+ implementation of the GNU shell command
+ *  GNU General Public License
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * OLD ADRESS:
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
- * NEW ADRESS:
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
- *
- * You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ *  This file is part of XCFA.
  * 
+ *  XCFA is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  at your option) any later version.
+ * 
+ *  XCFA is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ * 
+ *  You should have received a copy of the GNU General Public License
+ *  along with XCFA.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 
@@ -62,6 +56,7 @@
 #include "fileselect.h"
 #include "tags.h"
 #include "file.h"
+#include "statusbar.h"
 
 
 
@@ -725,7 +720,7 @@ DETAIL *FileMp3Ogg_get (TYPE_FILE_IS p_TypeFileIs, gint *p_type, gint *p_debit,
 void on_combobox_lame_abr_cbr_vbr_mp3ogg_realize (GtkWidget *widget, gpointer user_data)
 {
 	var_file_mp3ogg.Adr_Widget_Lame_abr_cbr_vbr = GTK_COMBO_BOX (widget);
-	libcombo_alloc (GTK_COMBO_BOX (widget));
+	// libcombo_alloc (GTK_COMBO_BOX (widget));
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "ABR");
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "CBR");
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "VBR");
@@ -1032,31 +1027,13 @@ gboolean FileMp3Ogg_event (GtkWidget *treeview, GdkEvent *event, gpointer user_d
 	gint                Pos_X = 0, Pos_Y = 0;
 	gint                i;
 	gboolean            BoolSelectColNom = FALSE;
-	gboolean            bool_dedans = FALSE;
-	
-	// SI SORTIE DU CONTEXTE
-	if (event->type == GDK_LEAVE_NOTIFY) {
-		bool_dedans = FALSE;
-		main_puts_statusbar_global ("");
-		return (FALSE);
-	}
-	// SINON SI ENTREE DANS LE CONTEXTE
-	else if (event->type == GDK_MOTION_NOTIFY)  {
-		bool_dedans = TRUE;
-	}
-
-	// SI PAS DANS LE CONTEXTE
-	if (bool_dedans == FALSE) {
-		main_puts_statusbar_global ("");
-		return (FALSE);
-	}
 	
 	// SI PAS DANS LE TREEVIEW
 	gdk_window_get_pointer (((GdkEventButton*)event)->window, &x, &y, &state);
 	if (FALSE == gtk_tree_view_get_path_at_pos (GTK_TREE_VIEW(treeview),
 					   x, y,
 					   &path, &column, &Pos_X, &Pos_Y)) {
-		main_puts_statusbar_global ("");
+		StatusBar_set_mess( NOTEBOOK_FICHIERS, _STATUSBAR_SIMPLE_, "" );
 		return (FALSE);
 	}
 	
@@ -1066,7 +1043,7 @@ gboolean FileMp3Ogg_event (GtkWidget *treeview, GdkEvent *event, gpointer user_d
 	if (NULL == detail) return (FALSE);
 	
 	// DANS TOUS LES CAS, EFFACE LA BARRE DE TACHE
-	main_puts_statusbar_global ("");
+	StatusBar_set_mess( NOTEBOOK_FICHIERS, _STATUSBAR_SIMPLE_, "" );
 
 	/* IDEE POUR REMPLACER LES COMPARAISON PAR NOMS. EXEMPLES:
 	 * 	PLAY	= 0
@@ -1081,16 +1058,21 @@ gboolean FileMp3Ogg_event (GtkWidget *treeview, GdkEvent *event, gpointer user_d
 		if (ColumnDum == column) {
 			switch ( i ) {
 			case NUM_TREE_FILEMP3OGG_Nom :		BoolSelectColNom		= TRUE;	break;
-			default: return (FALSE);
+			default: 
+				StatusBar_set_mess( NOTEBOOK_FICHIERS, _STATUSBAR_SIMPLE_, "");
+				StatusBar_puts();
+				return (FALSE);
 			}
 			/* La colonne est trouvee ... sortie de la boucle */
 			break;
 		}
 	}
 	if (BoolSelectColNom) {
-		main_puts_statusbar_global (detail->namefile);
+		StatusBar_set_mess( NOTEBOOK_FICHIERS, _STATUSBAR_SIMPLE_, detail->namefile);
 	}
 	
+	StatusBar_puts( );
+	
 	return (FALSE);
 }
 // 
