@@ -1,33 +1,27 @@
  /*
- * file      : file_scan_db.c
- * project   : xcfa
- * with      : Gtk-2
+ *  file      : file_scan_db.c
+ *  project   : xcfa
+ *  with      : Gtk-2
  *
- * copyright : (C) 2003 - 2011 by Claude Bulin
+ *  copyright : (C) 2003 - 2011 by Claude Bulin
  *
- * xcfa - GTK+ implementation of the GNU shell command
- * GNU General Public License
+ *  xcfa - GTK+ implementation of the GNU shell command
+ *  GNU General Public License
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * OLD ADRESS:
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
- * NEW ADRESS:
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
- *
- * You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ *  This file is part of XCFA.
  * 
+ *  XCFA is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  at your option) any later version.
+ * 
+ *  XCFA is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ * 
+ *  You should have received a copy of the GNU General Public License
+ *  along with XCFA.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 
@@ -56,6 +50,7 @@
 #include "configuser.h"
 #include "get_info.h"
 #include "win_scan.h"
+#include "popup_systray.h"
 #include "file.h"
 
 
@@ -209,6 +204,7 @@ static gint FileScanDB_timeout (gpointer data)
 	
 	if (VarFileScanDB.bool_thread_end == TRUE) {
 		if (FALSE == VarFileScanDB.BoolWindScanUsed) WindScan_close ();
+		PopupSystray_set_BoolMainAction (FALSE);
 		gtk_timeout_remove (VarFileScanDB.handler_timeout);
 	}
 	
@@ -230,6 +226,8 @@ void FileScanDB_action (gboolean BoolAllScan)
 		VarFileScanDB.bool_update = FALSE;
 		VarFileScanDB.MessUser = NULL;
 		
+		PopupSystray_set_BoolMainAction (TRUE);
+	
 		VarFileScanDB.BoolWindScanUsed = WindScan_open ("Scan dBFS", WINDSCAN_PULSE);
 		VarFileScanDB.handler_timeout = gtk_timeout_add (50, FileScanDB_timeout, 0);
 		pthread_create (&VarFileScanDB.nmr_tid, NULL ,(void *)FileScanDB_thread, (void *)NULL);
