@@ -1,33 +1,27 @@
  /*
- * file      : file_wav.c
- * project   : xcfa
- * with      : Gtk-2
+ *  file      : file_wav.c
+ *  project   : xcfa
+ *  with      : Gtk-2
  *
- * copyright : (C) 2003 - 2011 by Claude Bulin
+ *  copyright : (C) 2003 - 2011 by Claude Bulin
  *
- * xcfa - GTK+ implementation of the GNU shell command
- * GNU General Public License
+ *  xcfa - GTK+ implementation of the GNU shell command
+ *  GNU General Public License
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * OLD ADRESS:
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
- * NEW ADRESS:
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
- *
- * You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ *  This file is part of XCFA.
  * 
+ *  XCFA is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  at your option) any later version.
+ * 
+ *  XCFA is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ * 
+ *  You should have received a copy of the GNU General Public License
+ *  along with XCFA.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 
@@ -62,6 +56,7 @@
 #include "fileselect.h"
 #include "file.h"
 #include "popup.h"
+#include "statusbar.h"
 
 
 
@@ -586,41 +581,26 @@ gboolean FileWav_event (GtkWidget *treeview, GdkEvent *event, gpointer user_data
 	gboolean            BoolSelectColFREQUENCE = FALSE;
 	gboolean            BoolSelectColPISTE = FALSE;
 	gboolean            BoolSelectColQUANTIFICATION = FALSE;
-	gboolean            bool_dedans = FALSE;
-	
-	// SI SORTIE DU CONTEXTE
-	if (event->type == GDK_LEAVE_NOTIFY) {
-		bool_dedans = FALSE;
-		main_puts_statusbar_global ("");
-		return (FALSE);
-	}
-	// SINON SI ENTREE DANS LE CONTEXTE
-	else if (event->type == GDK_MOTION_NOTIFY)  {
-		bool_dedans = TRUE;
-	}
-
-	// SI PAS DANS LE CONTEXTE
-	if (bool_dedans == FALSE) {
-		main_puts_statusbar_global ("");
-		return (FALSE);
-	}
 	
 	// SI PAS DANS LE TREEVIEW
 	gdk_window_get_pointer (((GdkEventButton*)event)->window, &x, &y, &state);
 	if (FALSE == gtk_tree_view_get_path_at_pos (GTK_TREE_VIEW(treeview),
 					   x, y,
 					   &path, &column, &Pos_X, &Pos_Y)) {
-		main_puts_statusbar_global ("");
+		StatusBar_set_mess( NOTEBOOK_FICHIERS, _STATUSBAR_SIMPLE_, " ");
+		StatusBar_puts( );
 		return (FALSE);
 	}
 	
 	// RECUPERATION DE LA STRUCTURE POINTEE PAR LE CURSEUR SOURIS
 	gtk_tree_model_get_iter (model, &iter, path);
 	gtk_tree_model_get (var_file_wav.Adr_Tree_Model, &iter, COLUMN_FILEWAV_POINTER_STRUCT, &detail, -1);
-	if (NULL == detail) return (FALSE);
+	if (NULL == detail) {
+		return (FALSE);
+	}
 	
 	// DANS TOUS LES CAS, EFFACE LA BARRE DE TACHE
-	main_puts_statusbar_global ("");
+	StatusBar_set_mess( NOTEBOOK_FICHIERS, _STATUSBAR_SIMPLE_, "");
 
 	/* IDEE POUR REMPLACER LES COMPARAISON PAR NOMS. EXEMPLES:
 	 * 	PLAY	= 0
@@ -638,24 +618,29 @@ gboolean FileWav_event (GtkWidget *treeview, GdkEvent *event, gpointer user_data
 			case NUM_TREE_FILEWAV_PISTE :		BoolSelectColPISTE		= TRUE;	break;
 			case NUM_TREE_FILEWAV_QUANTIFICATION :	BoolSelectColQUANTIFICATION	= TRUE;	break;
 			case NUM_TREE_FILEWAV_Nom :		BoolSelectColNom		= TRUE;	break;
-			default: return (FALSE);
+			// default: return (FALSE);
+			default: break;
 			}
 			/* La colonne est trouvee ... sortie de la boucle */
 			break;
 		}
 	}
 	if (TRUE == BoolSelectColFREQUENCE) {
-		main_puts_statusbar_global (_("(Click Droit = Menu) / Choix de la frequence"));
+		StatusBar_set_mess( NOTEBOOK_FICHIERS, _STATUSBAR_SIMPLE_, _("(Click Droit = Menu) / Choix de la frequence"));
 	}
 	else if (TRUE == BoolSelectColPISTE) {
-		main_puts_statusbar_global (_("(Click Droit = Menu) / Choix du nombre de pistes (voies)"));
+		StatusBar_set_mess( NOTEBOOK_FICHIERS, _STATUSBAR_SIMPLE_, _("(Click Droit = Menu) / Choix du nombre de pistes (voies)"));
 	}
 	else if (TRUE == BoolSelectColQUANTIFICATION) {
-		main_puts_statusbar_global (_("(Click Droit = Menu) / Choix du codage en nombre de bits"));
+		StatusBar_set_mess( NOTEBOOK_FICHIERS, _STATUSBAR_SIMPLE_, _("(Click Droit = Menu) / Choix du codage en nombre de bits"));
 	}
 	else if (TRUE == BoolSelectColNom) {
-		main_puts_statusbar_global (detail->namefile);
+		StatusBar_set_mess( NOTEBOOK_FICHIERS, _STATUSBAR_SIMPLE_, detail->namefile);
 	}
+	else {
+		StatusBar_set_mess( NOTEBOOK_FICHIERS, _STATUSBAR_SIMPLE_, " ");
+	}
+	StatusBar_puts( );
 	
 	return (FALSE);
 }
