@@ -1,33 +1,27 @@
  /*
- * file      : file_wav_conv.c
- * project   : xcfa
- * with      : Gtk-2
+ *  file      : file_wav_conv.c
+ *  project   : xcfa
+ *  with      : Gtk-2
  *
- * copyright : (C) 2003 - 2011 by Claude Bulin
+ *  copyright : (C) 2003 - 2011 by Claude Bulin
  *
- * xcfa - GTK+ implementation of the GNU shell command
- * GNU General Public License
+ *  xcfa - GTK+ implementation of the GNU shell command
+ *  GNU General Public License
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * OLD ADRESS:
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
- * NEW ADRESS:
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
- *
- * You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ *  This file is part of XCFA.
  * 
+ *  XCFA is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  at your option) any later version.
+ * 
+ *  XCFA is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ * 
+ *  You should have received a copy of the GNU General Public License
+ *  along with XCFA.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 
@@ -61,6 +55,7 @@
 #include "notify_send.h"
 #include "win_scan.h"
 #include "conv.h"
+#include "popup_systray.h"
 #include "file.h"
 
 
@@ -296,6 +291,8 @@ static gint filewavconv_timeout (gpointer data)
 		CONV_FIC_WAV	*PConvWav = NULL;
 		DETAIL		*detail = NULL;
 		
+		PopupSystray_set_BoolMainAction (FALSE);
+		
 		gtk_timeout_remove (conv.handler_timeout_conv);
 		WindScan_close ();
 	
@@ -445,6 +442,8 @@ void filewavconv_apply (void)
 	conv_reset_struct (WindScan_close_request);
 	filewavconv_set_flags_before ();
 
+	PopupSystray_set_BoolMainAction (TRUE);
+	
 	conv.bool_thread_conv = TRUE;
 	conv.handler_timeout_conv = gtk_timeout_add (50, filewavconv_timeout, 0);
  	pthread_create (&nmr_tid, NULL ,(void *)filewavconv_thread, (void *)NULL);
