@@ -1,33 +1,27 @@
  /*
- * file      : fileselect.c
- * project   : xcfa
- * with      : Gtk-2
+ *  file      : fileselect.c
+ *  project   : xcfa
+ *  with      : Gtk-2
  *
- * copyright : (C) 2003 - 2011 by Claude Bulin
+ *  copyright : (C) 2003 - 2011 by Claude Bulin
  *
- * xcfa - GTK+ implementation of the GNU shell command
- * GNU General Public License
+ *  xcfa - GTK+ implementation of the GNU shell command
+ *  GNU General Public License
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * OLD ADRESS:
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
- * NEW ADRESS:
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
- *
- * You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ *  This file is part of XCFA.
  * 
+ *  XCFA is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  at your option) any later version.
+ * 
+ *  XCFA is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ * 
+ *  You should have received a copy of the GNU General Public License
+ *  along with XCFA.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 
@@ -370,7 +364,7 @@ void fileselect_remove_comment (void)
 void fileselect_init_comment (void)
 {
 	Select[ _PATH_CHOICE_DESTINATION_ ].Title	= g_strdup (_("Choix d'un dossier de destination"));
-	Select[ _PATH_LOAD_SPLIT_FILE_ ].Title		= g_strdup (_("Choix d'un fichier CUE WAV FLAC OGG MP3 APE"));
+	Select[ _PATH_LOAD_SPLIT_FILE_ ].Title		= g_strdup (_("Choix d'un fichier CUE WAV FLAC OGG MP3 APE WMA"));
 	Select[ _PATH_LOAD_ONE_FILE_ ].Title		= g_strdup (_("Choix d'un fichier"));
 	Select[ _PATH_LOAD_FILE_ALL_ ].Title		= g_strdup (_("Choix de fichiers"));
 	Select[ _PATH_LOAD_FILE_WAV_ ].Title		= g_strdup (_("Choix de fichiers WAV"));
@@ -459,9 +453,13 @@ void fileselect_create (TYPE_FILESELECTION Choice, gchar *Path, void *Func_Exter
 			gtk_file_filter_add_pattern (filter, "*.MP3");
 			gtk_file_filter_add_pattern (filter, "*.ape");
 			gtk_file_filter_add_pattern (filter, "*.APE");
+			
+			gtk_file_filter_add_pattern (filter, "*.wma");
+			gtk_file_filter_add_pattern (filter, "*.WMA");
+			
 			gtk_file_filter_add_pattern (filter, "*.cue");
 			gtk_file_filter_add_pattern (filter, "*.CUE");
-			gtk_file_filter_set_name (filter, _("*.wav *.flac *.ogg *.mp3 *.ape *.cue"));
+			gtk_file_filter_set_name (filter, "*.wav *.flac *.ogg *.mp3 *.ape *.wma *.cue");
 			gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (filechooserdialog), filter);
 			
 			filter = gtk_file_filter_new ();
@@ -494,6 +492,12 @@ void fileselect_create (TYPE_FILESELECTION Choice, gchar *Path, void *Func_Exter
 			gtk_file_filter_add_pattern (filter, "*.APE");
 			gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (filechooserdialog), filter);
 			
+			filter = gtk_file_filter_new ();
+			gtk_file_filter_set_name (filter, "WMA (*.wma)");
+			gtk_file_filter_add_pattern (filter, "*.wma");
+			gtk_file_filter_add_pattern (filter, "*.WMA");
+			gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (filechooserdialog), filter);
+
 			filter = gtk_file_filter_new ();
 			gtk_file_filter_set_name (filter, "CUE (*.cue)");
 			gtk_file_filter_add_pattern (filter, "*.cue");
