@@ -1,33 +1,27 @@
  /*
- * file      : get_info.c
- * project   : xcfa
- * with      : Gtk-2
+ *  file      : get_info.c
+ *  project   : xcfa
+ *  with      : Gtk-2
  *
- * copyright : (C) 2003 - 2011 by Claude Bulin
+ *  copyright : (C) 2003 - 2011 by Claude Bulin
  *
- * xcfa - GTK+ implementation of the GNU shell command
- * GNU General Public License
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * OLD ADRESS:
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
- * NEW ADRESS:
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
- *
- * You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ *  xcfa - GTK+ implementation of the GNU shell command
+ *  GNU General Public License
  *
+ *  This file is part of XCFA.
+ * 
+ *  XCFA is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  at your option) any later version.
+ * 
+ *  XCFA is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ * 
+ *  You should have received a copy of the GNU General Public License
+ *  along with XCFA.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 
@@ -427,6 +421,8 @@ void GetInfo_cpu_print (void)
 	ModelName = GetInfo_cpu ();
 
 	HostConf.NbCpu   = sysconf(_SC_NPROCESSORS_ONLN);
+	// g_print ("_SC_NPROCESSORS_CONF : Le nombre de processeurs configure                           = %d\n", (gint)sysconf(_SC_NPROCESSORS_CONF));
+	// g_print ("_SC_NPROCESSORS_ONLN : Le nombre de processeurs actuellement en ligne (disponibles) = %d\n", (gint)sysconf(_SC_NPROCESSORS_ONLN));
 	HostConf.TypeCpu = 8 * sizeof(void*);
 	if (uname (&utsname) == 0) {
 		
@@ -773,18 +769,18 @@ void GetInfo_eject (gchar *StrDevice)
 	gint     size = 0;
 
 	args[pos++] = "eject";
-	args[pos++] = "--cdrom";
+	// args[pos++] = "--cdrom";
 	args[pos++] = StrDevice;
 	args[pos++] = NULL;
 
-	/*
+	
 	g_print ("!-----------------------------------!\n");
 	g_print ("!              E J E C T            !\n");
 	g_print ("!-----------------------------------!\n");
 	for (pos = 0; args[ pos ] != NULL; pos++)
 		g_print ("args [ %02d ] = '%s'\n", pos, args [ pos ]);
 	g_print ("\n");
-	*/
+	
 
 	fd = GetInfo_exec_with_output (args, &VarGet.code_fork, STDERR_FILENO);
 	do {
@@ -912,20 +908,26 @@ gboolean GetInfo_wget (void)
 	gint     size = 0;
 	gboolean bool_access_ok = TRUE;
 
+	// PRINT_FUNC_LF();
+	
 	args[pos++] = "wget";
 	args[pos++] = "--user-agent=\"Mozilla 22.0\"";
 	args[pos++] = "--directory-prefix=/tmp/";
 	args[pos++] = "http://www.google.fr/index.html";
 	args[pos++] = NULL;
 	args[pos++] = NULL;
-
-	/*g_print ("!-----------------------------------!\n");
+	
+	
+	/*
+	g_print ("!-----------------------------------!\n");
 	g_print ("!             W G E T               !\n");
 	g_print ("!-----------------------------------!\n");
 	for (pos = 0; args[ pos ] != NULL; pos++)
 		g_print ("args [ %02d ] = '%s'\n", pos, args [ pos ]);
-	g_print ("\n");*/
-
+	g_print ("\n");
+	*/
+	
+	
 	fd = GetInfo_exec_with_output (args, &VarGet.code_fork, STDERR_FILENO);
 	do {
 		pos = -1;
@@ -1092,7 +1094,7 @@ TYPE_FILE_IS GetInfo_file_is (gchar *PathName)
 			 strstr (gstr->str, "MPEG ADTS, layer III") ||
 			 strstr (gstr->str, "XWD X Window Dump image data")) {
 			 TypeFileRet = FILE_IS_MP3;
-			 PRINT("IS MP3");
+			// PRINT("IS MP3");
 		}
 		else if (strstr (gstr->str, "Ogg data") && strstr (gstr->str, "Vorbis audio")) {
 			TypeFileRet = FILE_IS_OGG;
