@@ -1,33 +1,27 @@
  /*
- * file      : main.c
- * project   : xcfa
- * with      : Gtk-2
+ *  file      : main.c
+ *  project   : xcfa
+ *  with      : Gtk-2
  *
- * copyright : (C) 2003 - 2011 by Claude Bulin
+ *  copyright : (C) 2003 - 2011 by Claude Bulin
  *
- * xcfa - GTK+ implementation of the GNU shell command
- * GNU General Public License
+ *  xcfa - GTK+ implementation of the GNU shell command
+ *  GNU General Public License
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * OLD ADRESS:
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
- * NEW ADRESS:
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
- *
- * You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ *  This file is part of XCFA.
  * 
+ *  XCFA is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  at your option) any later version.
+ * 
+ *  XCFA is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ * 
+ *  You should have received a copy of the GNU General Public License
+ *  along with XCFA.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 
@@ -73,33 +67,13 @@
 #include "split.h"
 #include "alsa_play.h"
 #include "win_info.h"
+#include "popup_systray.h"
+#include "statusbar.h"
 #include "global.h"
 
 
-/*
-GStaticMutex cmd_queue_lock;
-g_static_mutex_init(&ad.cmd_queue_lock);
-    
-int give_me_next_number ()
-
-{
-
-	static int current_number = 0;
-
-	int ret_val;
-
-	static GStaticMutex mutex = G_STATIC_MUTEX_INIT;
-	
-	g_static_mutex_lock (&mutex);
-
-	ret_val = current_number++;
-
-	g_static_mutex_unlock (&mutex);
-
-	return ret_val;
-
-}   
-   */ 
+// FIXME
+// TODO
 
 GtkBuilder	*GtkXcfaProjet = NULL;
 GtkWidget	*WindMain = NULL;
@@ -127,97 +101,6 @@ KEYS keys = {
 };
 
 
-static GList *pixmaps_directories = NULL;
-
-// This is an internally used function to find pixmap files.
-// 
-static gchar *find_pixmap_file (const gchar *filename)
-{
-	GList *elem;
-
-	/* We step through each of the pixmaps directory to find it. */
-	elem = pixmaps_directories;
-	while (elem)
-	{
-		gchar *pathname = g_strdup_printf ("%s%s%s", (gchar*)elem->data, G_DIR_SEPARATOR_S, filename);
-		if (g_file_test (pathname, G_FILE_TEST_EXISTS)) return pathname;
-		g_free (pathname);
-		elem = elem->next;
-	}
-	return NULL;
-}
-
-// This is an internally used function to create pixmaps.
-// 
-GtkWidget *create_pixmap (GtkWidget *widget, const gchar *filename)
-{
-	gchar *pathname = NULL;
-	GtkWidget *pixmap;
-
-	if (!filename || !filename[0]) return gtk_image_new ();
-
-	pathname = find_pixmap_file (filename);
-
-	if (!pathname)
-	{
-		g_warning (_("Couldn't find pixmap file: %s"), filename);
-		return gtk_image_new ();
-	}
-
-	pixmap = gtk_image_new_from_file (pathname);
-	g_free (pathname);
-	return pixmap;
-}
-// 
-// 
-void main_puts_statusbar_global (gchar *mess_label_status)
-{
-	static	gboolean Bool_puts_statusbar_global = FALSE;
-	
-	if (NULL != AdrLabelStatusbarGlobal && FALSE == Bool_puts_statusbar_global) {
-		
-		// NO ACESS IN PROC
-		Bool_puts_statusbar_global = TRUE;
-		
-		gchar *New_Str = NULL;
-		gchar *NewName = g_strnfill (strlen(mess_label_status) * 4, '\0');
-		gchar *NewPtr = NewName;
-		gchar *ptr = mess_label_status;
-		
-		while (*ptr) {
-			if (*ptr == '&') {
-				*NewPtr ++ = *ptr ++;
-				*NewPtr ++ = 'a';
-				*NewPtr ++ = 'm';
-				*NewPtr ++ = 'p';
-				*NewPtr ++ = ';';
-			}
-			else {
-				*NewPtr ++ = *ptr ++;
-			}
-		}
-		
-		// New_Str = g_strdup_printf ("<span font_desc=\"sans %d\"><span color=\"black\"><b>%s</b></span></span>", 9, NewName);
-		New_Str = g_strdup_printf ("<span color=\"black\"><b>%s</b></span>", NewName);
-		
-		gtk_label_set_justify (GTK_LABEL (AdrLabelStatusbarGlobal), GTK_JUSTIFY_CENTER);
-		
-		// TODO : @Tetsumaki  http://forum.ubuntu-fr.org/viewtopic.php?pid=3889380#p3889380
-		// TODO : bug avec: while ...
-		// while (gtk_events_pending()) gtk_main_iteration(); 
-		
-		gtk_label_set_use_markup (GTK_LABEL (AdrLabelStatusbarGlobal), TRUE);
-		gtk_label_set_markup (GTK_LABEL (AdrLabelStatusbarGlobal), New_Str);
-
-		g_free (New_Str);
-		New_Str = NULL;
-		g_free (NewName);
-		NewName = NULL;
-		
-		// ACESS IN PROC IS OK
-		Bool_puts_statusbar_global = FALSE;
-	}
-}
 // 
 // 
 void on_label_statusbar_global_realize (GtkWidget *widget, gpointer user_data)
@@ -308,6 +191,8 @@ void remove_memory_apply (void)
 		g_print ("g_unlink (%s)\n", SPLIT_FILE_TMP_WAV);
 		g_unlink (SPLIT_FILE_TMP_WAV);
 	}
+	g_print ("StatusBar_remove ()\n");
+	StatusBar_remove();
 
 	g_print ("\n");
 }
@@ -315,6 +200,7 @@ void remove_memory_apply (void)
 // 
 void on_notebook_general_switch_page (GtkNotebook *notebook, GtkNotebookPage *page, guint page_num, gpointer user_data)
 {
+
 	if (TRUE == Config.BoolConfigOk) {
 		Config.NotebookGeneral = page_num;
 		
@@ -322,7 +208,7 @@ void on_notebook_general_switch_page (GtkNotebook *notebook, GtkNotebookPage *pa
 			split_set_name_file ();
 		}
 		else {
-			main_puts_statusbar_global ("");
+			StatusBar_puts();
 		}
 	}
 }
@@ -361,6 +247,8 @@ void on_notebook_in_file_switch_page (GtkNotebook *notebook, GtkNotebookPage *pa
 			gtk_combo_box_set_active (GTK_COMBO_BOX (var_file.Adr_combobox_DestFile), Config.TabIndiceComboDestFile[ NOTEBOOK_FICHIERS_TAGS ]);
 			break;
 		}
+		StatusBar_set_mess( NOTEBOOK_FICHIERS, _STATUSBAR_SIMPLE_, "" );
+		StatusBar_puts();
 	}
 }
 // 
@@ -626,7 +514,7 @@ gint main (gint argc, gchar *argv[], gchar **envp)
 	gchar	*PathShareProjet = NULL;
 	gchar	*Path = NULL;
 	gchar	*PackageVersion = NULL;
-	
+
 	// g_mem_set_vtable (glib_mem_profiler_table);
 	
 	if (TRUE == process_exist_file ()) {
@@ -754,15 +642,18 @@ gint main (gint argc, gchar *argv[], gchar **envp)
 	
 	libutils_set_default_icone_to_win (WindMain);
 	
+	// SYSTRAY: CREATION DE L'ICONE DE STATUS + INFO-BULLE
+	PopupSystray_init ();
+	
 	gtk_widget_show (WindMain);
 	
+	// NOTEBOOK
 	gtk_notebook_set_current_page (GTK_NOTEBOOK (GLADE_GET_OBJECT("notebook_general")), NOTEBOOK_PRGEXTERNES);
 		gtk_notebook_set_current_page (GTK_NOTEBOOK (GLADE_GET_OBJECT("notebook_app_externes")), NOTEBOOK_OPTIONS_EXTRA);
 		gtk_notebook_set_current_page (GTK_NOTEBOOK (GLADE_GET_OBJECT("notebook_app_externes")), NOTEBOOK_OPTIONS_PRGEXTERNES);
 		
 	// OPTIONS
 	gtk_notebook_set_current_page (GTK_NOTEBOOK (GLADE_GET_OBJECT("notebook_general")), NOTEBOOK_OPTIONS);
-		
 		gtk_notebook_set_current_page (GTK_NOTEBOOK (GLADE_GET_OBJECT("notebook_options")), NOTEBOOK_OPTIONS_EXPORT_TAGS);
 		gtk_notebook_set_current_page (GTK_NOTEBOOK (GLADE_GET_OBJECT("notebook_options")), NOTEBOOK_OPTIONS_AACPLUSENC);
 		gtk_notebook_set_current_page (GTK_NOTEBOOK (GLADE_GET_OBJECT("notebook_options")), NOTEBOOK_OPTIONS_FAAC);
@@ -781,7 +672,7 @@ gint main (gint argc, gchar *argv[], gchar **envp)
 		gtk_notebook_set_current_page (GTK_NOTEBOOK (GLADE_GET_OBJECT("notebook_pochette")), NOTEBOOK_POCHETTE_TITRE);
 		gtk_notebook_set_current_page (GTK_NOTEBOOK (GLADE_GET_OBJECT("notebook_pochette")), NOTEBOOK_POCHETTE_IMAGE);
 
-	// NOTEBOOK_SPLIT
+	// SPLIT
 	gtk_notebook_set_current_page (GTK_NOTEBOOK (GLADE_GET_OBJECT("notebook_general")), NOTEBOOK_SPLIT);
 
 	// FICHIERS
@@ -831,13 +722,10 @@ gint main (gint argc, gchar *argv[], gchar **envp)
 	
 	filetrash_test_trash_is_ok ();
 	
-	// INHIBER LE JOURNAL DE LOGS
-	gtk_widget_set_sensitive (GTK_WIDGET (GLADE_GET_OBJECT("frame_journal")), FALSE);
-		
 	// SI CHARGEMENT DE FICHIERS DEPUIS LE BUREAU AVEC LE MENU CONTEXTUEL
 	process_goto_timeout ();
 	
-	// ADMINISTRATOR MOD ?
+	// ADMINISTRATOR MODE ?
 	if (0 == getuid()) {
 		wininfo_create (
 			_("MODE ADMINISTRATEUR"),
