@@ -1,33 +1,27 @@
  /*
- * file      : options_cd.c
- * project   : xcfa
- * with      : Gtk-2
+ *  file      : options_cd.c
+ *  project   : xcfa
+ *  with      : Gtk-2
  *
- * copyright : (C) 2003 - 2011 by Claude Bulin
+ *  copyright : (C) 2003 - 2011 by Claude Bulin
  *
- * xcfa - GTK+ implementation of the GNU shell command
- * GNU General Public License
+ *  xcfa - GTK+ implementation of the GNU shell command
+ *  GNU General Public License
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * OLD ADRESS:
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
- * NEW ADRESS:
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
- *
- * You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ *  This file is part of XCFA.
  * 
+ *  XCFA is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  at your option) any later version.
+ * 
+ *  XCFA is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ * 
+ *  You should have received a copy of the GNU General Public License
+ *  along with XCFA.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 
@@ -56,23 +50,6 @@
 #include "options.h"
 
 
-void on_radiobutton_cdparanoia_realize (GtkWidget *widget, gpointer user_data)
-{
-	var_options.Adr_radiobutton_cdparanoia = widget;
-}
-void on_radiobutton_ioctl_realize (GtkWidget *widget, gpointer user_data)
-{
-	var_options.Adr_radiobutton_ioctl = widget;
-	gtk_toggle_button_set_active ( GTK_TOGGLE_BUTTON(var_options.Adr_radiobutton_ioctl), Config.ReadCdByIoctl);
-}
-void on_radiobutton_ioctl_clicked (GtkButton *button, gpointer user_data)
-{
-	Config.ReadCdByIoctl = TRUE;
-}
-void on_radiobutton_cdparanoia_clicked (GtkButton *button, gpointer user_data)
-{
-	Config.ReadCdByIoctl = FALSE;
-}
 
 
 void on_radiobutton_choice_extract_with_clicked (GtkButton *button, gpointer user_data)
