@@ -1,33 +1,27 @@
  /*
- * file      : options_mp3.c
- * project   : xcfa
- * with      : Gtk-2
+ *  file      : options_mp3.c
+ *  project   : xcfa
+ *  with      : Gtk-2
  *
- * copyright : (C) 2003 - 2011 by Claude Bulin
+ *  copyright : (C) 2003 - 2011 by Claude Bulin
  *
- * xcfa - GTK+ implementation of the GNU shell command
- * GNU General Public License
+ *  xcfa - GTK+ implementation of the GNU shell command
+ *  GNU General Public License
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * OLD ADRESS:
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
- * NEW ADRESS:
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
- *
- * You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ *  This file is part of XCFA.
  * 
+ *  XCFA is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  at your option) any later version.
+ * 
+ *  XCFA is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ * 
+ *  You should have received a copy of the GNU General Public License
+ *  along with XCFA.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 
@@ -230,7 +224,7 @@ gchar *optionsLame_get_str_val_mode_lame (void)
 
 void on_combobox_lame_abr_cbr_vbr_realize (GtkWidget *widget, gpointer user_data)
 {
-	libcombo_alloc (GTK_COMBO_BOX (widget));
+	// libcombo_alloc (GTK_COMBO_BOX (widget));
 	
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "ABR");
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "CBR");
@@ -248,8 +242,9 @@ void on_combobox_lame_abr_cbr_vbr_changed (GtkComboBox *combobox, gpointer user_
 	if (NULL == var_options.Adr_Widget_Lame_bitrate) return;
 	if ((ind = gtk_combo_box_get_active (GTK_COMBO_BOX (var_options.Adr_Widget_Lame_abr_cbr_vbr))) < 0) return;
 	Config.BitrateLameIndice = ind;
-	libcombo_alloc (GTK_COMBO_BOX (var_options.Adr_Widget_Lame_bitrate));
-
+	// libcombo_alloc (GTK_COMBO_BOX (var_options.Adr_Widget_Lame_bitrate));
+	libcombo_remove_options (GTK_COMBO_BOX (var_options.Adr_Widget_Lame_bitrate));
+	
 	switch (Config.BitrateLameIndice) {
 	
 	/* ABR 0 .. 13 */
