@@ -1,33 +1,27 @@
  /*
- * file      : split_selector.c
- * project   : xcfa
- * with      : Gtk-2
+ *  file      : split_selector.c
+ *  project   : xcfa
+ *  with      : Gtk-2
  *
- * copyright : (C) 2003 - 2011 by Claude Bulin
+ *  copyright : (C) 2003 - 2011 by Claude Bulin
  *
- * xcfa - GTK+ implementation of the GNU shell command
- * GNU General Public License
+ *  xcfa - GTK+ implementation of the GNU shell command
+ *  GNU General Public License
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * OLD ADRESS:
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
- * NEW ADRESS:
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
- *
- * You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ *  This file is part of XCFA.
  * 
+ *  XCFA is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  at your option) any later version.
+ * 
+ *  XCFA is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ * 
+ *  You should have received a copy of the GNU General Public License
+ *  along with XCFA.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 
@@ -50,10 +44,10 @@
 #include "global.h"
 #include "alsa_play.h"
 #include "split.h"
+#include "statusbar.h"
+
 
 
-/* TODO : INSERER DANS LES STRUCTURE LE POINT 
-*/
 
 extern VAR_SPLIT VarSplit;
 
@@ -69,8 +63,8 @@ void DEBUG_PRINT_SplitSelector (void)
 		if (-1 != VarSplit.Selecteur [ IndiceSrc ] . Nmr) {
 			g_print ("[ %2d ]  Begin = %6d   End = %6d\t",
 					IndiceSrc,
-					(gint)VarSplit.Selecteur [ IndiceSrc ] . Begin,
-					(gint)VarSplit.Selecteur [ IndiceSrc ] . End
+					(gint)VarSplit.Selecteur [ IndiceSrc ] . BeginPaint,
+					(gint)VarSplit.Selecteur [ IndiceSrc ] . EndPaint
 					);
 			g_print ("PercentBegin = %2.6f   PercentEnd = %2.6f\n",
 					VarSplit.Selecteur [ IndiceSrc ] . PercentBegin,
@@ -94,39 +88,12 @@ void SplitSelector_init (void)
 	VarSplit.BoolBlankWithCue = FALSE;
 	for (Cpt = 0; Cpt < MAX_SELECTEURS_SPLIT; Cpt ++) {
 		VarSplit.Selecteur [ Cpt ] . Nmr = -1;
-		VarSplit.Selecteur [ Cpt ] . Begin = -1;
-		VarSplit.Selecteur [ Cpt ] . End = -1;
+		VarSplit.Selecteur [ Cpt ] . BeginPaint = -1;
+		VarSplit.Selecteur [ Cpt ] . EndPaint = -1;
 		VarSplit.Selecteur [ Cpt ] . PercentBegin =
 		VarSplit.Selecteur [ Cpt ] . PercentEnd = 0.0;
 	}
 }
-// 
-// button_actualise_split
-/*
-void on_button_actualise_split_clicked (GtkButton *button, gpointer user_data)
-{
-	gint IndicePoints;
-	
-	PRINT_FUNC_LF();
-	
-	// INIT STRUCTURES: Selecteur
-	SplitSelector_init ();
-	
-	SplitSpectre_search_blank_pass (VarSplit.nTotalChunckSize / 2352);
-	
-	for (IndicePoints = 0; IndicePoints < MAX_SELECTEURS_SPLIT; IndicePoints ++) {
-		if (-1 != VarSplit.Selecteur [ IndicePoints ] . Nmr) {
-			VarSplit.NbrSelecteurs ++;
-		}
-	}
-	
-	SplitSelector_get_pos ();
-	
-	split_set_flag_buttons ();
-	split_set_time ();
-	gtk_widget_queue_draw (VarSplit.AdrWidgetSpectre);
-}
-*/
 // SELECTEUR: IL N EN RESTERA QU UN  ;-)
 // 
 void on_button_del_cut_split_clicked (GtkButton *button, gpointer user_data)
@@ -137,19 +104,20 @@ void on_button_del_cut_split_clicked (GtkButton *button, gpointer user_data)
 		
 		DEBUG_PRINT_SplitSelector ();
 		
-		// INIT STRUCTURES: Selecteur ET Points50DB
+		// INIT STRUCTURES: Selecteur ET Points 50 db
 		SplitSelector_init ();
 		VarSplit.SelecteurActif = 0;
 		VarSplit.NbrSelecteurs = 1;
 		VarSplit.Selecteur [ 0 ] . Nmr = 0;
-		VarSplit.Selecteur [ 0 ] . Begin = 0;
-		VarSplit.Selecteur [ 0 ] . End = VarSplit.SpectreW;
+		VarSplit.Selecteur [ 0 ] . BeginPaint = 0;
+		VarSplit.Selecteur [ 0 ] . EndPaint = (SplitSpectre_get_with() -1 );
 		VarSplit.Selecteur [ 0 ] . PercentBegin =
 		VarSplit.Selecteur [ 0 ] . PercentEnd = 0.0;
-		VarSplit.Selecteur [ 0 ] . PercentBegin = ((gdouble)VarSplit.Selecteur [ 0 ] . Begin / (gdouble)VarSplit.AdrWidgetSpectre->allocation.width) * 100.0;
-		VarSplit.Selecteur [ 0 ] . PercentEnd   = ((gdouble)VarSplit.Selecteur [ 0 ] . End / (gdouble)VarSplit.AdrWidgetSpectre->allocation.width) * 100.0;
+		VarSplit.Selecteur [ 0 ] . PercentBegin = ((gdouble)VarSplit.Selecteur [ 0 ] . BeginPaint / (gdouble)SplitSpectre_get_with() ) * 100.0;
+		VarSplit.Selecteur [ 0 ] . PercentEnd   = ((gdouble)VarSplit.Selecteur [ 0 ] . EndPaint / (gdouble)SplitSpectre_get_with() ) * 100.0;
 		
 		gtk_widget_queue_draw (VarSplit.AdrWidgetSpectre);
+		gtk_widget_queue_draw( VarSplit.AdrWidgetSpectreTop );
 		
 		DEBUG_PRINT_SplitSelector ();
 		split_set_flag_buttons ();
@@ -159,7 +127,7 @@ void on_button_del_cut_split_clicked (GtkButton *button, gpointer user_data)
 // 
 void SplitSelector_cut (void)
 {
-#define	        MESS_ERR_CUT "<span color=\"red\">Suppression pendant la lecture impossible</span>"
+#define	        MESS_ERR_CUT "Suppression pendant la lecture impossible"
 	if (0 == VarSplit.NbrSelecteurs) {
 		PRINT("\tAUCUN SELECTEUR  !!!");
 	}
@@ -169,7 +137,7 @@ void SplitSelector_cut (void)
 	else if (VarSplit.NbrSelecteurs > 1) {
 		
 		if (TRUE == AlsaPlay_is_play ()) {
-			main_puts_statusbar_global (_(MESS_ERR_CUT));
+			StatusBar_set_mess( NOTEBOOK_SPLIT, _STATUSBAR_WARN_, _(MESS_ERR_CUT) );
 		}
 		else {
 			gint	Zone = 0;
@@ -188,13 +156,10 @@ void SplitSelector_cut (void)
 			if (VarSplit.SelecteurActif >= VarSplit.NbrSelecteurs -1 && VarSplit.SelecteurActif > 0) VarSplit.SelecteurActif --;
 			
 			VarSplit.Selecteur [ VarSplit.NbrSelecteurs ] . Nmr = -1;
-			VarSplit.Selecteur [ VarSplit.NbrSelecteurs ] . Begin = -1;
-			VarSplit.Selecteur [ VarSplit.NbrSelecteurs ] . End = -1;
+			VarSplit.Selecteur [ VarSplit.NbrSelecteurs ] . BeginPaint = -1;
+			VarSplit.Selecteur [ VarSplit.NbrSelecteurs ] . EndPaint = -1;
 			VarSplit.Selecteur [ VarSplit.NbrSelecteurs ] . PercentBegin =
 			VarSplit.Selecteur [ VarSplit.NbrSelecteurs ] . PercentEnd = 0.0;
-			
-			gtk_widget_queue_draw (VarSplit.AdrWidgetSpectre);
-			split_set_flag_buttons ();
 		}
 	}
 }
@@ -259,16 +224,16 @@ void SplitSelector_add (gint p_CursorX)
 		// 
 		// --
 		// 
-		PercentCursorX = ((gdouble)CursorX / (gdouble)VarSplit.AdrWidgetSpectre->allocation.width) * 100.0;
+		PercentCursorX = ((gdouble)CursorX / (gdouble)SplitSpectre_get_with() ) * 100.0;
 		Len = SplitSelector_get_diff_sec (0.0, PercentCursorX);
 		if (Len < 5) {
-			main_puts_statusbar_global (_("<span color=\"red\">Temps inferieur a 5 secondes entre marqueur et curseur !</span>"));
+			StatusBar_set_mess( NOTEBOOK_SPLIT, _STATUSBAR_WARN_, _("Temps inferieur a 5 secondes entre marqueur et curseur !") );
 			return;
 		}
 		
 		Len = SplitSelector_get_diff_sec (PercentCursorX, VarSplit.Selecteur [ 0 ] . PercentBegin);
 		if (Len < 5) {
-			main_puts_statusbar_global (_("<span color=\"red\">Temps inferieur a 5 secondes entre marqueur et curseur !</span>"));
+			StatusBar_set_mess( NOTEBOOK_SPLIT, _STATUSBAR_WARN_, _("Temps inferieur a 5 secondes entre marqueur et curseur !") );
 			return;
 		}
 		
@@ -279,7 +244,7 @@ void SplitSelector_add (gint p_CursorX)
 		if (VarSplit.NbrSelecteurs < MAX_SELECTEURS_SPLIT) {
 			for (IndiceDest = VarSplit.NbrSelecteurs; IndiceDest > 0; IndiceDest --) {
 				IndiceSrc = IndiceDest -1;
-				g_print ("\tg_memmove(%d, %d, %lu);\n", IndiceDest, IndiceSrc, sizeof(SELECTEUR));
+				g_print ("\tg_memmove(%d, %d, %d);\n", IndiceDest, IndiceSrc, (gint)sizeof(SELECTEUR));
 				g_memmove(&VarSplit.Selecteur [ IndiceDest ], &VarSplit.Selecteur [ IndiceSrc ], sizeof(SELECTEUR));
 			}
 		}
@@ -299,10 +264,10 @@ void SplitSelector_add (gint p_CursorX)
 		}
 		g_print ("VarSplit.Selecteur [ %d ] . Nmr = %d\n",IndiceSrc, VarSplit.Selecteur [ IndiceSrc ] . Nmr);
 		
-		VarSplit.Selecteur [ VarSplit.SelecteurActif ] . Begin        = CursorX;
-		VarSplit.Selecteur [ VarSplit.SelecteurActif ] . PercentBegin = ((gdouble)CursorX / (gdouble)VarSplit.AdrWidgetSpectre->allocation.width) * 100.0;
+		VarSplit.Selecteur [ VarSplit.SelecteurActif ] . BeginPaint   = CursorX;
+		VarSplit.Selecteur [ VarSplit.SelecteurActif ] . PercentBegin = ((gdouble)CursorX / (gdouble)SplitSpectre_get_with() ) * 100.0;
 		
-		VarSplit.Selecteur [ VarSplit.SelecteurActif ] . End        = VarSplit.Selecteur [ VarSplit.SelecteurActif +1 ] . Begin;
+		VarSplit.Selecteur [ VarSplit.SelecteurActif ] . EndPaint   = VarSplit.Selecteur [ VarSplit.SelecteurActif +1 ] . BeginPaint;
 		VarSplit.Selecteur [ VarSplit.SelecteurActif ] . PercentEnd = VarSplit.Selecteur [ VarSplit.SelecteurActif +1 ] . PercentBegin;
 	}
 	// 
@@ -314,16 +279,16 @@ void SplitSelector_add (gint p_CursorX)
 		// 
 		// --
 		// 
-		PercentCursorX = ((gdouble)CursorX / (gdouble)VarSplit.AdrWidgetSpectre->allocation.width) * 100.0;
+		PercentCursorX = ((gdouble)CursorX / (gdouble)SplitSpectre_get_with() ) * 100.0;
 		Len = SplitSelector_get_diff_sec (VarSplit.Selecteur [ 0 ] . PercentEnd, PercentCursorX);
 		if (Len < 5) {
-			main_puts_statusbar_global (_("<span color=\"red\">Temps inferieur a 5 secondes entre marqueur et curseur !</span>"));
+			StatusBar_set_mess( NOTEBOOK_SPLIT, _STATUSBAR_WARN_, _("Temps inferieur a 5 secondes entre marqueur et curseur !") );
 			return;
 		}
 		
 		Len = SplitSelector_get_diff_sec (PercentCursorX, 100.0);
 		if (Len < 5) {
-			main_puts_statusbar_global (_("<span color=\"red\">Temps inferieur a 5 secondes entre marqueur et curseur !</span>"));
+			StatusBar_set_mess( NOTEBOOK_SPLIT, _STATUSBAR_WARN_, _("Temps inferieur a 5 secondes entre marqueur et curseur !") );
 			return;
 		}
 		
@@ -334,7 +299,7 @@ void SplitSelector_add (gint p_CursorX)
 		if (VarSplit.NbrSelecteurs < MAX_SELECTEURS_SPLIT) {
 			for (IndiceDest = VarSplit.NbrSelecteurs; IndiceDest > VarSplit.NbrSelecteurs -1; IndiceDest --) {
 				IndiceSrc = IndiceDest -1;
-				g_print ("\tg_memmove(%d, %d, %lu);\n", IndiceDest, IndiceSrc, sizeof(SELECTEUR));
+				g_print ("\tg_memmove(%d, %d, %d);\n", IndiceDest, IndiceSrc, (gint)sizeof(SELECTEUR));
 				g_memmove(&VarSplit.Selecteur [ IndiceDest ], &VarSplit.Selecteur [ IndiceSrc ], sizeof(SELECTEUR));
 			}
 		}
@@ -354,11 +319,12 @@ void SplitSelector_add (gint p_CursorX)
 		}
 		g_print ("VarSplit.Selecteur [ %d ] . Nmr = %d\n",IndiceSrc, VarSplit.Selecteur [ IndiceSrc ] . Nmr);
 		
-		VarSplit.Selecteur [ VarSplit.SelecteurActif ] . Begin        = CursorX;
-		VarSplit.Selecteur [ VarSplit.SelecteurActif ] . PercentBegin = ((gdouble)CursorX / (gdouble)VarSplit.AdrWidgetSpectre->allocation.width) * 100.0;
+		VarSplit.Selecteur [ VarSplit.SelecteurActif ] . BeginPaint   = CursorX;
+		VarSplit.Selecteur [ VarSplit.SelecteurActif ] . PercentBegin = ((gdouble)CursorX / (gdouble)SplitSpectre_get_with() ) * 100.0;
 
-		VarSplit.Selecteur [ VarSplit.SelecteurActif ] . End        = VarSplit.SpectreW ;
-		VarSplit.Selecteur [ VarSplit.SelecteurActif ] . PercentEnd = ((gdouble)VarSplit.SpectreW  / (gdouble)VarSplit.AdrWidgetSpectre->allocation.width) * 100.0;
+		VarSplit.Selecteur [ VarSplit.SelecteurActif ] . EndPaint   = VARSPLIT_SPECTRE_W ;
+		VarSplit.Selecteur [ VarSplit.SelecteurActif ] . PercentEnd = ((gdouble)VARSPLIT_SPECTRE_W  / (gdouble)SplitSpectre_get_with() ) * 100.0;
+		
 	}
 	else {
 		for (Cpt = 0; Cpt <= VarSplit.NbrSelecteurs; Cpt ++) {
@@ -370,16 +336,18 @@ void SplitSelector_add (gint p_CursorX)
 				// 
 				// --
 				// 
-				PercentCursorX = ((gdouble)CursorX / (gdouble)VarSplit.AdrWidgetSpectre->allocation.width) * 100.0;
+				PercentCursorX = ((gdouble)CursorX / (gdouble)SplitSpectre_get_with() ) * 100.0;
 				Len = SplitSelector_get_diff_sec (VarSplit.Selecteur [ Cpt ] . PercentBegin, PercentCursorX);
 				if (Len < 5) {
-					main_puts_statusbar_global (_("<span color=\"red\">Temps inferieur a 5 secondes entre marqueur et curseur !</span>"));
+				PRINT("1- if (Len < 5) {");
+					StatusBar_set_mess( NOTEBOOK_SPLIT, _STATUSBAR_WARN_, _("Temps inferieur a 5 secondes entre marqueur et curseur !") );
 					return;
 				}
 				
 				Len = SplitSelector_get_diff_sec (PercentCursorX, VarSplit.Selecteur [ Cpt ] . PercentEnd);
 				if (Len < 5) {
-					main_puts_statusbar_global (_("<span color=\"red\">Temps inferieur a 5 secondes entre marqueur et curseur !</span>"));
+				PRINT("2- if (Len < 5) {");
+					StatusBar_set_mess( NOTEBOOK_SPLIT, _STATUSBAR_WARN_, _("Temps inferieur a 5 secondes entre marqueur et curseur !") );
 					return;
 				}
 		
@@ -390,7 +358,7 @@ void SplitSelector_add (gint p_CursorX)
 				if (VarSplit.NbrSelecteurs < MAX_SELECTEURS_SPLIT) {
 					for (IndiceDest = VarSplit.NbrSelecteurs; IndiceDest > Cpt; IndiceDest --) {
 						IndiceSrc = IndiceDest -1;
-						g_print ("\tg_memmove(%d, %d, %lu);\n", IndiceDest, IndiceSrc, sizeof(SELECTEUR));
+						g_print ("\tg_memmove(%d, %d, %d);\n", IndiceDest, IndiceSrc, (gint)sizeof(SELECTEUR));
 						g_memmove(&VarSplit.Selecteur [ IndiceDest ], &VarSplit.Selecteur [ IndiceSrc ], sizeof(SELECTEUR));
 					}
 				}
@@ -412,25 +380,25 @@ void SplitSelector_add (gint p_CursorX)
 				
 				/*
 				RESLOLU @Dzef
-				VarSplit.Selecteur [ VarSplit.SelecteurActif ] . Begin         = CursorX;
-				VarSplit.Selecteur [ VarSplit.SelecteurActif ] . PercentBegin  = ((gdouble)CursorX / (gdouble)VarSplit.AdrWidgetSpectre->allocation.width) * 100.0;
+				VarSplit.Selecteur [ VarSplit.SelecteurActif ] . BeginPaint    = CursorX;
+				VarSplit.Selecteur [ VarSplit.SelecteurActif ] . PercentBegin  = ((gdouble)CursorX / (gdouble)SplitSpectre_get_with() ) * 100.0;
 				if (CursorX + 50 < VarSplit.SpectreW)
 					CursorX += 50;
 				else	CursorX = VarSplit.SpectreW;
-				VarSplit.Selecteur [ VarSplit.SelecteurActif ] . End           = CursorX;
-				VarSplit.Selecteur [ VarSplit.SelecteurActif ] . PercentEnd    = ((gdouble)CursorX / (gdouble)VarSplit.AdrWidgetSpectre->allocation.width) * 100.0;
+				VarSplit.Selecteur [ VarSplit.SelecteurActif ] . EndPaint      = CursorX;
+				VarSplit.Selecteur [ VarSplit.SelecteurActif ] . PercentEnd    = ((gdouble)CursorX / (gdouble)SplitSpectre_get_with() ) * 100.0;
 				*/
 				// end 0  = end -1
-				VarSplit.Selecteur [ VarSplit.SelecteurActif ] . End           = VarSplit.Selecteur [ VarSplit.SelecteurActif -1 ] . End;
+				VarSplit.Selecteur [ VarSplit.SelecteurActif ] . EndPaint      = VarSplit.Selecteur [ VarSplit.SelecteurActif -1 ] . EndPaint;
 				VarSplit.Selecteur [ VarSplit.SelecteurActif ] . PercentEnd    = VarSplit.Selecteur [ VarSplit.SelecteurActif -1 ] . PercentEnd;
 				
 				// end -1 = cursorX
-				VarSplit.Selecteur [ VarSplit.SelecteurActif -1 ] . End           = CursorX;
-				VarSplit.Selecteur [ VarSplit.SelecteurActif -1 ] . PercentEnd    = ((gdouble)CursorX / (gdouble)VarSplit.AdrWidgetSpectre->allocation.width) * 100.0;
+				VarSplit.Selecteur [ VarSplit.SelecteurActif -1 ] . EndPaint      = CursorX;
+				VarSplit.Selecteur [ VarSplit.SelecteurActif -1 ] . PercentEnd    = ((gdouble)CursorX / (gdouble)SplitSpectre_get_with() ) * 100.0;
 				
 				// Begin  = cursorX
-				VarSplit.Selecteur [ VarSplit.SelecteurActif ] . Begin         = CursorX;
-				VarSplit.Selecteur [ VarSplit.SelecteurActif ] . PercentBegin  = ((gdouble)CursorX / (gdouble)VarSplit.AdrWidgetSpectre->allocation.width) * 100.0;
+				VarSplit.Selecteur [ VarSplit.SelecteurActif ] . BeginPaint    = CursorX;
+				VarSplit.Selecteur [ VarSplit.SelecteurActif ] . PercentBegin  = ((gdouble)CursorX / (gdouble)SplitSpectre_get_with() ) * 100.0;
 				break;
 			}
 			// 
@@ -441,16 +409,16 @@ void SplitSelector_add (gint p_CursorX)
 				// 
 				// --
 				// 
-				PercentCursorX = ((gdouble)CursorX / (gdouble)VarSplit.AdrWidgetSpectre->allocation.width) * 100.0;
+				PercentCursorX = ((gdouble)CursorX / (gdouble)SplitSpectre_get_with() ) * 100.0;
 				Len = SplitSelector_get_diff_sec (VarSplit.Selecteur [ Cpt ] . PercentEnd, PercentCursorX);
 				if (Len < 5) {
-					main_puts_statusbar_global (_("<span color=\"red\">Temps inferieur a 5 secondes entre marqueur et curseur !</span>"));
+					StatusBar_set_mess( NOTEBOOK_SPLIT, _STATUSBAR_WARN_, _("Temps inferieur a 5 secondes entre marqueur et curseur !") );
 					return;
 				}
 				
 				Len = SplitSelector_get_diff_sec (PercentCursorX, VarSplit.Selecteur [ Cpt +1 ] . PercentBegin);
 				if (Len < 5) {
-					main_puts_statusbar_global (_("<span color=\"red\">Temps inferieur a 5 secondes entre marqueur et curseur !</span>"));
+					StatusBar_set_mess( NOTEBOOK_SPLIT, _STATUSBAR_WARN_, _("Temps inferieur a 5 secondes entre marqueur et curseur !") );
 					return;
 				}
 		
@@ -461,7 +429,7 @@ void SplitSelector_add (gint p_CursorX)
 				if (VarSplit.NbrSelecteurs < MAX_SELECTEURS_SPLIT) {
 					for (IndiceDest = VarSplit.NbrSelecteurs; IndiceDest > Cpt; IndiceDest --) {
 						IndiceSrc = IndiceDest -1;
-						g_print ("\tg_memmove(%d, %d, %lu);\n", IndiceDest, IndiceSrc, sizeof(SELECTEUR));
+						g_print ("\tg_memmove(%d, %d, %d);\n", IndiceDest, IndiceSrc, (gint)sizeof(SELECTEUR));
 						g_memmove(&VarSplit.Selecteur [ IndiceDest ], &VarSplit.Selecteur [ IndiceSrc ], sizeof(SELECTEUR));
 					}
 				}
@@ -481,17 +449,17 @@ void SplitSelector_add (gint p_CursorX)
 				}
 				g_print ("VarSplit.Selecteur [ %d ] . Nmr = %d\n",IndiceSrc, VarSplit.Selecteur [ IndiceSrc ] . Nmr);
 				
-				VarSplit.Selecteur [ VarSplit.SelecteurActif ] . Begin         = CursorX;
-				VarSplit.Selecteur [ VarSplit.SelecteurActif ] . PercentBegin  = ((gdouble)CursorX / (gdouble)VarSplit.AdrWidgetSpectre->allocation.width) * 100.0;
+				VarSplit.Selecteur [ VarSplit.SelecteurActif ] . BeginPaint    = CursorX;
+				VarSplit.Selecteur [ VarSplit.SelecteurActif ] . PercentBegin  = ((gdouble)CursorX / (gdouble)SplitSpectre_get_with() ) * 100.0;
 				
-				VarSplit.Selecteur [ VarSplit.SelecteurActif ] . End           = VarSplit.Selecteur [ VarSplit.SelecteurActif +1 ] . Begin;
+				VarSplit.Selecteur [ VarSplit.SelecteurActif ] . EndPaint      = VarSplit.Selecteur [ VarSplit.SelecteurActif +1 ] . BeginPaint;
 				VarSplit.Selecteur [ VarSplit.SelecteurActif ] . PercentEnd    = VarSplit.Selecteur [ VarSplit.SelecteurActif +1 ] . PercentBegin;
 				
 				break;
 			}
 		}
 	}	
-	gtk_widget_queue_draw (VarSplit.AdrWidgetSpectre);
+	// gtk_widget_queue_draw (VarSplit.AdrWidgetSpectre);
 }
 // 
 // TRANSFORME 4 SECONDES EN PIXELS ET RETOUR
@@ -527,7 +495,7 @@ gint SplitSelector_get_4_secondes_to_int (void)
 		S = sec % 60;
 		C = hundr;
 		if (H == 0 && M == 0 && S == 5) {
-			Len = (gint)(((gdouble)VarSplit.AdrWidgetSpectre->allocation.width * Percent) / 100.0);
+			Len = (gint)(((gdouble)SplitSpectre_get_with()  * Percent) / 100.0);
 			break;
 		}
 		if (Cpt > 100000 && S == 0) break;
@@ -581,8 +549,9 @@ void SplitSelector_get_pos (void)
 	gint	Cpt;
 	
 	for (Cpt = 0; Cpt < MAX_SELECTEURS_SPLIT; Cpt ++) {
-		VarSplit.Selecteur [ Cpt ] . Begin = (gint)(((gdouble)VarSplit.AdrWidgetSpectre->allocation.width * VarSplit.Selecteur [ Cpt ] . PercentBegin) / 100.0);
-		VarSplit.Selecteur [ Cpt ] . End   = (gint)(((gdouble)VarSplit.AdrWidgetSpectre->allocation.width * VarSplit.Selecteur [ Cpt ] . PercentEnd) / 100.0);
+		
+		VarSplit.Selecteur [ Cpt ] . BeginPaint  = (gint)(((gdouble)SplitSpectre_get_with()  * VarSplit.Selecteur [ Cpt ] . PercentBegin) / 100.0);
+		VarSplit.Selecteur [ Cpt ] . EndPaint    = (gint)(((gdouble)SplitSpectre_get_with()  * VarSplit.Selecteur [ Cpt ] . PercentEnd) / 100.0);
 	}
 }
 // 
@@ -591,57 +560,43 @@ void SplitSelector_get_pos (void)
 void SplitSelector_set_pos_begin (gint p_begin)
 {
 	gint	TimeForSec = SplitSelector_get_4_secondes_to_int ();
-	/*gint	Len;
-	gint	PosSelecteurActif;
+	gint	With       = SplitSpectre_get_with();
 	
 	// PRINT_FUNC_LF();
 	
-	if (-1 != (PosSelecteurActif = SplitSelector_get_PosSelecteurActif (p_begin))) {
-		Len = SplitSelector_get_diff_sec (VarSplit.Selecteur [ PosSelecteurActif ] . PercentBegin, VarSplit.Selecteur [ PosSelecteurActif ] . PercentEnd);
-		g_print("PosSelecteurActif = %d  Len = %d\n", PosSelecteurActif, Len);
-		if (Len < 5) {
-			main_puts_statusbar_global (_("Le temps entre deux marqueurs doit etre superieur a 5 secondes"));
-			// return;
-		}
-	}*/
-
 	if (-1 == TimeForSec) return;	
 	if (p_begin < 0) p_begin = 0;
-	if (p_begin > VarSplit.SpectreW) p_begin = VarSplit.SpectreW;
-	if (p_begin + TimeForSec >= VarSplit.SpectreW) return;
+	if (p_begin > With) p_begin = With;
+	if (p_begin + TimeForSec >= With) return;
 	
 	if (VarSplit.SelecteurActif > 0) {
 
 		// VERS LE PRECEDENT
 
-		if (p_begin < VarSplit.Selecteur [ VarSplit.SelecteurActif -1 ] . Begin + TimeForSec) {
-			p_begin = VarSplit.Selecteur [ VarSplit.SelecteurActif -1 ] . Begin + TimeForSec;
-			VarSplit.Selecteur [ VarSplit.SelecteurActif -1 ] . PercentEnd =
-					((gdouble)p_begin / (gdouble)VarSplit.AdrWidgetSpectre->allocation.width) * 100.0;
+		if (p_begin < VarSplit.Selecteur [ VarSplit.SelecteurActif -1 ] . BeginPaint + TimeForSec) {
+			p_begin = VarSplit.Selecteur [ VarSplit.SelecteurActif -1 ] . BeginPaint + TimeForSec;
+			VarSplit.Selecteur [ VarSplit.SelecteurActif -1 ] . PercentEnd = ((gdouble)p_begin / (gdouble)With ) * 100.0;
 		}
-		if (p_begin < VarSplit.Selecteur [ VarSplit.SelecteurActif -1 ] . End) {
-			VarSplit.Selecteur [ VarSplit.SelecteurActif -1 ] . PercentEnd =
-					((gdouble)p_begin / (gdouble)VarSplit.AdrWidgetSpectre->allocation.width) * 100.0;
+		if (p_begin < VarSplit.Selecteur [ VarSplit.SelecteurActif -1 ] . EndPaint) {
+			VarSplit.Selecteur [ VarSplit.SelecteurActif -1 ] . PercentEnd = ((gdouble)p_begin / (gdouble)With ) * 100.0;
 		}
 		
 	}
-		// VERS LE SUIVANT
-		
-		if (VarSplit.SelecteurActif  < VarSplit.NbrSelecteurs -1 &&
-		    p_begin > VarSplit.Selecteur [ VarSplit.SelecteurActif +1 ] . Begin - TimeForSec) {
-			
-			p_begin = VarSplit.Selecteur [ VarSplit.SelecteurActif +1 ] . Begin - TimeForSec;
-		}
-		
-		if (p_begin > VarSplit.Selecteur [ VarSplit.SelecteurActif ] . End - TimeForSec) {
-			VarSplit.Selecteur [ VarSplit.SelecteurActif ] .        End = p_begin + TimeForSec;
-			VarSplit.Selecteur [ VarSplit.SelecteurActif ] . PercentEnd =
-					((gdouble)(p_begin + TimeForSec) / (gdouble)VarSplit.AdrWidgetSpectre->allocation.width) * 100.0;
-		}
-		
 	
-	VarSplit.Selecteur [ VarSplit.SelecteurActif  ] . PercentBegin =
-			((gdouble)p_begin / (gdouble)VarSplit.AdrWidgetSpectre->allocation.width) * 100.0;
+	// VERS LE SUIVANT
+	
+	if (VarSplit.SelecteurActif  < VarSplit.NbrSelecteurs -1 &&
+	    p_begin > VarSplit.Selecteur [ VarSplit.SelecteurActif +1 ] . BeginPaint - TimeForSec) {
+		
+		p_begin = VarSplit.Selecteur [ VarSplit.SelecteurActif +1 ] . BeginPaint - TimeForSec;
+	}
+	
+	if (p_begin > VarSplit.Selecteur [ VarSplit.SelecteurActif ] . EndPaint - TimeForSec) {
+		VarSplit.Selecteur [ VarSplit.SelecteurActif ] . EndPaint   = p_begin + TimeForSec;
+		VarSplit.Selecteur [ VarSplit.SelecteurActif ] . PercentEnd = ((gdouble)(p_begin + TimeForSec) / (gdouble)With ) * 100.0;
+	}	
+	
+	VarSplit.Selecteur [ VarSplit.SelecteurActif  ] . PercentBegin = ((gdouble)p_begin / (gdouble)With ) * 100.0;
 		
 	SplitSelector_get_pos ();
 }
@@ -650,63 +605,50 @@ void SplitSelector_set_pos_begin (gint p_begin)
 // 
 void SplitSelector_set_pos_end (gint p_end)
 {
-	gint	TimeForSec = SplitSelector_get_4_secondes_to_int ();
-	/*gint	Len;
-	gint	PosSelecteurActif;
+	gint	TimeForSec = SplitSelector_get_4_secondes_to_int();
+	gint	With       = SplitSpectre_get_with();
 	
 	// PRINT_FUNC_LF();
 	
-	if (-1 != (PosSelecteurActif = SplitSelector_get_PosSelecteurActif (p_end))) {
-		Len = SplitSelector_get_diff_sec (VarSplit.Selecteur [ PosSelecteurActif ] . PercentBegin, VarSplit.Selecteur [ PosSelecteurActif ] . PercentEnd);
-		g_print("PosSelecteurActif = %d  Len = %d\n", PosSelecteurActif, Len);
-		if (Len < 5) {
-			main_puts_statusbar_global (_("Le temps entre deux marqueurs doit etre superieur a 5 secondes"));
-			return;
-		}
-	}*/
-	
 	if (-1 == TimeForSec) return;
 	if (p_end < 0) p_end = 0;
-	if (p_end > VarSplit.SpectreW) p_end = VarSplit.SpectreW;
+	if( p_end > With ) p_end = With - 2;
 	
 	// LE SELECTEUR DE FIN DOIT BUTTER SUR LE SELECTEUR SUIVANT
 	if (VarSplit.NbrSelecteurs -1 > VarSplit.SelecteurActif) {
-		if (p_end > VarSplit.Selecteur [ VarSplit.SelecteurActif +1 ] . Begin) {
-			p_end = VarSplit.Selecteur [ VarSplit.SelecteurActif +1 ] . Begin;
+		if (p_end > VarSplit.Selecteur [ VarSplit.SelecteurActif +1 ] . BeginPaint) {
+			p_end = VarSplit.Selecteur [ VarSplit.SelecteurActif +1 ] . BeginPaint;
 		}
 	}
 	
 	// BUTTEE SUR SELECTEUR DE DEBUT
 	// CHEVAUCHEMENT D INDEX INTERDIT ! PREVOIR ESPACE DE 4 SECONDES
-	if (p_end < VarSplit.Selecteur [ VarSplit.SelecteurActif ] . Begin + TimeForSec)
-		p_end = VarSplit.Selecteur [ VarSplit.SelecteurActif ] . Begin + TimeForSec;	
+	if (p_end < VarSplit.Selecteur [ VarSplit.SelecteurActif ] . BeginPaint + TimeForSec)
+		p_end = VarSplit.Selecteur [ VarSplit.SelecteurActif ] . BeginPaint + TimeForSec;	
 	
-	VarSplit.Selecteur [ VarSplit.SelecteurActif ] . End = p_end;
-	VarSplit.Selecteur [ VarSplit.SelecteurActif ] . PercentEnd = ((gdouble)VarSplit.Selecteur [ VarSplit.SelecteurActif ] . End / (gdouble)VarSplit.AdrWidgetSpectre->allocation.width) * 100.0;
+	VarSplit.Selecteur [ VarSplit.SelecteurActif ] . EndPaint   = p_end;
+	VarSplit.Selecteur [ VarSplit.SelecteurActif ] . PercentEnd = ((gdouble)VarSplit.Selecteur [ VarSplit.SelecteurActif ] . EndPaint / (gdouble)With ) * 100.0;
 }
 // 
 // 
 gint SplitSelector_get_pos_begin (gint p_Sel)
 {
-	SplitSpectre_get_pos_widget ();
 	SplitSelector_get_pos ();
 
-	return (VarSplit.Selecteur [ p_Sel ] . Begin);
+	return( VarSplit.Selecteur [ p_Sel ] . BeginPaint );
 }
 // 
 // 
 gint SplitSelector_get_pos_end (gint p_Sel)
 {
-	SplitSpectre_get_pos_widget ();
 	SplitSelector_get_pos ();
 
-	return (VarSplit.Selecteur [ p_Sel ] . End);
+	return (VarSplit.Selecteur [ p_Sel ] . EndPaint);
 }
 // 
 // 
 gdouble SplitSelector_get_percent_begin (gint p_Sel)
 {
-	SplitSpectre_get_pos_widget ();
 	SplitSelector_get_pos ();
 
 	return (VarSplit.Selecteur [ p_Sel ] . PercentBegin);
@@ -715,7 +657,6 @@ gdouble SplitSelector_get_percent_begin (gint p_Sel)
 // 
 gdouble SplitSelector_get_percent_end (gint p_Sel)
 {
-	SplitSpectre_get_pos_widget ();
 	SplitSelector_get_pos ();
 
 	return (VarSplit.Selecteur [ p_Sel ] . PercentEnd);
@@ -725,7 +666,7 @@ gdouble SplitSelector_get_percent_end (gint p_Sel)
 // 
 gint SplitSelector_get_pos_play (void)
 {
-	return ((gint)(((gdouble)VarSplit.AdrWidgetSpectre->allocation.width * VarSplit.PercentActivePlay) / 100.0));
+	return ((gint)(((gdouble)SplitSpectre_get_with()  * VarSplit.PercentActivePlay) / 100.0));
 }
 // 
 // 
@@ -736,7 +677,7 @@ gboolean SplitSelector_cursor_in_box_play (gint p_cursor_x, gint p_cursor_y)
 		gint	SelPlay = SplitSelector_get_pos_play ();
 		
 		if (p_cursor_x > SelPlay -6 && p_cursor_x < SelPlay +7)
-			if (p_cursor_y > VarSplit.ImgY + VarSplit.ImgH -12 && p_cursor_y < VarSplit.ImgY + VarSplit.ImgH)
+			if (p_cursor_y > VARSPLIT_SPECTRE_Y + VARSPLIT_SPECTRE_H -12 && p_cursor_y < VARSPLIT_SPECTRE_Y + VARSPLIT_SPECTRE_H)
 				return (TRUE);
 	}
 	return (FALSE);
@@ -752,7 +693,7 @@ gboolean SplitSelector_cursor_in_line_play (gint p_cursor_x, gint p_cursor_y)
 		if (p_cursor_x    == SelPlay ||
 		    p_cursor_x +1 == SelPlay ||
 		    p_cursor_x -1 == SelPlay) {
-			if (p_cursor_y > VarSplit.ImgY && p_cursor_y < VarSplit.ImgY + VarSplit.ImgH)
+			if (p_cursor_y > VARSPLIT_SPECTRE_Y && p_cursor_y < VARSPLIT_SPECTRE_Y + VARSPLIT_SPECTRE_H)
 				return (TRUE);
 		}
 	}
@@ -762,10 +703,12 @@ gboolean SplitSelector_cursor_in_line_play (gint p_cursor_x, gint p_cursor_y)
 // 
 void SplitSelector_set_pos_play (gint p_play)
 {
-	if (p_play < 0) p_play = 0;
-	if (p_play > VarSplit.SpectreW) p_play = VarSplit.SpectreW;
+	gint	With       = SplitSpectre_get_with();
 	
-	VarSplit.PercentActivePlay = ((gdouble)p_play / (gdouble)VarSplit.AdrWidgetSpectre->allocation.width) * 100.0;
+	if( p_play < 0 ) p_play = 0;
+	if( p_play > With ) p_play = With;
+	
+	VarSplit.PercentActivePlay = ((gdouble)p_play / (gdouble)With ) * 100.0;
 }
 
 
@@ -775,32 +718,3 @@ void SplitSelector_set_pos_play (gint p_play)
 
 
 
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
