@@ -1,33 +1,27 @@
  /*
- * file      : win_reader.c
- * project   : xcfa
- * with      : Gtk-2
+ *  file      : win_reader.c
+ *  project   : xcfa
+ *  with      : Gtk-2
  *
- * copyright : (C) 2003 - 2011 by Claude Bulin
+ *  copyright : (C) 2003 - 2011 by Claude Bulin
  *
- * xcfa - GTK+ implementation of the GNU shell command
- * GNU General Public License
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * OLD ADRESS:
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
- * NEW ADRESS:
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
- *
- * You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ *  xcfa - GTK+ implementation of the GNU shell command
+ *  GNU General Public License
  *
+ *  This file is part of XCFA.
+ * 
+ *  XCFA is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  at your option) any later version.
+ * 
+ *  XCFA is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ * 
+ *  You should have received a copy of the GNU General Public License
+ *  along with XCFA.  If not, see <http://www.gnu.org/licenses/>.
  */
  
  
@@ -50,6 +44,7 @@
 
 #include "global.h"
 #include "mplayer.h"
+#include "popup_systray.h"
 #include "win_reader.h"
 
 
@@ -135,6 +130,7 @@ gboolean on_WindReader_delete_event (GtkWidget *widget, GdkEvent *event, gpointe
 	mplayer_fifo_quit ();
 	VarWindReader.IsShow = FALSE;
 	gtk_widget_hide (VarWindReader.AdrWin);
+	PopupSystray_set_BoolMainAction (FALSE);
 	return TRUE;
 }
 // DESTROY EVENT
@@ -144,6 +140,7 @@ gboolean on_WindReader_destroy_event (GtkWidget *widget, GdkEvent *event, gpoint
 	mplayer_fifo_quit ();
 	VarWindReader.IsShow = FALSE;
 	gtk_widget_hide (VarWindReader.AdrWin);
+	PopupSystray_set_BoolMainAction (FALSE);
 	return TRUE;
 }
 // PAUSE
@@ -176,6 +173,7 @@ void on_button_quitter_WindReader_clicked (GtkButton *button, gpointer user_data
 	mplayer_fifo_quit ();
 	VarWindReader.IsShow = FALSE;
 	gtk_widget_hide (VarWindReader.AdrWin);
+	PopupSystray_set_BoolMainAction (FALSE);
 }
 // WIN-READER OPEN
 // 
@@ -205,6 +203,7 @@ void WinReader_open (gchar *title)
 	else {
 		gtk_widget_show (GTK_WIDGET (GLADE_GET_OBJECT("hbox_WindReader")));
 	}
+	PopupSystray_set_BoolMainAction (TRUE);
 }
 // WIN-READER SET-TITLE
 // 
@@ -238,6 +237,7 @@ void WinReader_close (void)
 		WinReader_set_lecture ();
 		VarWindReader.IsShow = FALSE;
 		gtk_widget_hide (VarWindReader.AdrWin);
+		PopupSystray_set_BoolMainAction (FALSE);
 	}
 }
 // WIN-READER IS OK
